# Nibe Heatpump Binding

The Nibe Heatpump binding is used to get live data from Nibe heat pumps without using an expensive MODBUS40 adapter.
This binding is compatible with the F750, F1145, F1245, F1155, F1255 and F470 heat pump models.

The binding supports data telegrams (containing a maximum of 20 registers) from the heat pump.
The binding can also read other registers from the pump.
It is recommended to add the most often updated variables to a telegram.
The binding will then read all other registers automatically from the pump when channels are linked to an item.
Register reading needs to be enabled in the thing configuration.
The binding also has experimental support for writing registers.
This can be used to configure the heat pump.
Write mode needs to be enabled in the thing configuration and for safety reasons all register identifiers need to be explicitly defined.

## Supported Things

This binding supports direct serial port connection (RS-485 adapter needed) to heat pump but also UDP connection via NibeGW software.

| Thing type      | Description                                      |
|-----------------|--------------------------------------------------|
| f1x45-serial    | Serial port connected F1145 and F1245 Heat Pumps |
| f1x45-udp       | UDP connected Nibe F1145 and F1245 Heat Pumps    |
| f1x45-simulator | Simulator for Nibe F1145 and F1245 Heat Pumps    |
| f1x55-serial    | Serial port connected F1155 and F1255 Heat Pumps |
| f1x55-udp       | UDP connected Nibe F1155 and F1255 Heat Pumps    |
| f1x55-simulator | Simulator for Nibe F1155 and F1255 Heat Pumps    |
| f750-serial     | Serial port connected F750 Heat Pumps            |
| f750-udp        | UDP connected Nibe F750 Heat Pumps               |
| f750-simulator  | Simulator for Nibe F750 Heat Pumps               |
| f470-serial     | Serial port connected F470 Heat Pumps            |
| f470-udp        | UDP connected Nibe F470 Heat Pumps               |
| f470-simulator  | Simulator for Nibe F470 Heat Pumps               |

## Discovery

Discovery is not supported, therefore the binding and things need to be configured via Paper UI or thing files. 

## Prerequisites

When Modbus adapter support is enabled from the heat pump UI, the heat pump will start to send telegrams every now and then.
A telegram contains a maximum of 20 registers.
Those 20 registers can be configured via the Nibe ModbusManager application.

Unfortunately Nibe has made this tricky.
A telegram from the heat pump must be acknowledged, otherwise the heat pump will raise an alarm and go into the alarm state.
Acknowledgement (ACK or NAK) responses should be sent correctly.
The binding also supports direct serial port connections to the heat pump, but the heat pump will raise an alarm when the openHAB binding is not running e.g. during openHAB updates.
This problem can be resolved by using the `nibegw` program, which can be run on Unix/Linux (such as a Raspberry Pi) or Arduino-based boards.
If you are running openHAB on a Raspberry Pi, the `nibegw` program can also run on the same machine.
Then when openHAB is not running , `nibegw` will acknowledge packets from the heat pump.
Obviously, this doesn't solve the problem when the Raspberry Pi is down, therefore an Arduino based solution is recommended.

`nibegw` is an application that reads telegrams from a serial port (which requires an RS-485 adapter), sends ACK/NAK to the heat pump and relays untouched telegrams to openHAB via UDP packets.
The Nibe Heat Pump binding will listen to a UDP port and parse register data from UDP telegrams.

### Arduino

An Arduino-based solution has been tested with Arduino uno + RS485 and Ethernet shields.
The [ProDiNo](https://www.kmpelectronics.eu/en-us/products/prodinoethernet.aspx) NetBoards are also supported.
A ProDiNo has an Ethernet and RS-485 port on the board.

Arduino code is available [here](https://github.com/openhab/openhab2-addons/tree/master/bundles/org.openhab.binding.nibeheatpump/contrib/NibeGW/Arduino/NibeGW).

Arduino code can be build via Arduino IDE.
For more details see [www.arduino.cc](https://www.arduino.cc/en/Main/Software). 
NibeGW configuration (such IP addresses, ports, etc) can be adapted directly by editing the code files.

### Raspberry Pi (or other Linux/Unix based boards)

C code is available [here](https://github.com/openhab/openhab2-addons/tree/master/bundles/org.openhab.binding.nibeheatpump/contrib/NibeGW/RasPi).

To build the C code use: 

```shell
gcc -std=gnu99 -o nibegw nibegw.c
```

For getting all command options execute the command using the help switch:

```shell
nibegw -h

./nibegw usage:

    -h                 Print help
    -v                 Print debug information
    -d <device name>   Serial port device (default: /dev/ttyS0)
    -a <address>       Remote host address (default: 127.0.0.1)
    -p <port>          Remote UDP port (default: 9999)
    -f                 Disable flow control (default: HW)
    -r <address>       RS-485 address to listen (default: 0x20)
    -i                 Send all messages by UDP (default: only modbus data)
    -n                 Don't send acknowledge at all
    -o                 Send acknowledge to all addresses
    -t                 Test mode
    -l <port>          Local UDP port for read commands (default: 9999)
    -w <port>          Local UDP port for write commands (default: 10000)
    -q                 Print data in log format

```

Usage example:

```shell
nibegw -v -d /dev/ttyUSB0 -a 192.168.1.10
```

## Binding Configuration

No binding configuration required.

## Thing Configuration

Things can be fully configured via Paper UI.
The following information is useful when configuring things via thing configuration files.

### UDP connection

Thing examples:

```
nibeheatpump:f1x45-udp:myPump [hostName="192.168.1.50", port=9999]
```

```
nibeheatpump:f1x45-udp:myPump [hostName="192.168.1.50", port=9999, readCommandsPort=10000, writeCommandsPort=10001, refreshInterval=30, enableReadCommands=true, enableWriteCommands=true, enableWriteCommandsToRegisters="44266, 47004"]
```

All supported configuration parameters for UDP connection:

| Property                        | Type    | Default | Required | Description |
|---------------------------------|---------|---------|----------|-------------|
| hostName                        | String  |         | Yes      | Network address of the Nibe heat pump |
| port                            | Integer | 9999    | No       | UDP port to listening data packets from the NibeGW |
| readCommandsPort                | Integer | 9999    | No       | UDP port to send read commands to the NibeGW |
| writeCommandsPort               | Integer | 10000   | No       | UDP port to send write commands to the NibeGW |
| refreshInterval                 | Integer | 60      | No       | States how often a refresh shall occur in seconds |
| enableReadCommands              | Boolean | false   | No       | Enable read commands to read additional variable from Nibe heat pump which are not included to data readout messages. This is experimental feature, use it at your own risk! |
| enableWriteCommands             | Boolean | false   | No       | Enable write commands to change Nibe heat pump settings. This is experimental feature, use it at your own risk! |
| enableWriteCommandsToRegisters  | String  |         | No       | Comma separated list of registers, which are allowed to write to Nibe heat pump. E.g. 44266, 47004 |
| throttleTime                    | Integer | 0       | No       | Throttle incoming data read out messages from heat pump. 0 = throttle is disabled, otherwise throttle time in milliseconds. |

### Serial port connection

Thing example:

```
nibeheatpump:f1x45-serial:myPump [serialPort="/dev/ttyUSB0"]
```


All supported configuration parameters for serial port connection:

| Property                        | Type    | Default | Required | Description |
|---------------------------------|---------|---------|----------|-------------|
| serialPort                      | String  |         | Yes      | Network address of the Nibe heat pump |
| refreshInterval                 | Integer | 60      | No       | States how often a refresh shall occur in seconds |
| enableReadCommands              | Boolean | false   | No       | Enable read commands to read additional variable from Nibe heat pump which are not included to data readout messages. This is experimental feature, use it at your own risk! |
| enableWriteCommands             | Boolean | false   | No       | Enable write commands to change Nibe heat pump settings. This is experimental feature, use it at your own risk! |
| enableWriteCommandsToRegisters  | String  |         | No       | Comma separated list of registers, which are allowed to write to Nibe heat pump. E.g. 44266, 47004 |
| sendAckToMODBUS40               | Boolean | true    | No       | Binding emulates MODBUS40 device and send protocol acknowledges to heat pump |
| sendAckToRMU40                  | Boolean | false   | No       | Binding emulates RMU40 device and send protocol acknowledges to heat pump |
| sendAckToSMS40                  | Boolean | false   | No       | Binding emulates SMS40 device and send protocol acknowledges to heat pump |
| throttleTime                    | Integer | 0       | No       | Throttle incoming data read out messages from heat pump. 0 = throttle is disabled, otherwise throttle time in milliseconds. |


## Channels

### F1x45

This binding currently supports following channels for F1x45 pump models:

| Channel Type ID | Item Type | Min         | Max        | Type    | Description                                              | Values                                                                                                                                                             |
|-----------------|-----------|-------------|------------|---------|----------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 40004           | Number    | -32767      | 32767      | Setting | BT1 Outdoor temp                                         |                                                                                                                                                                    |
| 40005           | Number    | -32767      | 32767      | Setting | EP23-BT2 Supply temp S4                                  |                                                                                                                                                                    |
| 40006           | Number    | -32767      | 32767      | Setting | EP22-BT2 Supply temp S3                                  |                                                                                                                                                                    |
| 40007           | Number    | -32767      | 32767      | Setting | EP21-BT2 Supply temp S2                                  |                                                                                                                                                                    |
| 40008           | Number    | -32767      | 32767      | Setting | BT2 Supply temp S1                                       |                                                                                                                                                                    |
| 40012           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT3 Return temp                               |                                                                                                                                                                    |
| 40013           | Number    | -32767      | 32767      | Setting | BT7 Hot Water top                                        |                                                                                                                                                                    |
| 40014           | Number    | -32767      | 32767      | Setting | BT6 Hot Water load                                       |                                                                                                                                                                    |
| 40015           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 40016           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 40017           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 40018           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 40019           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 40022           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 40025           | Number    | -32767      | 32767      | Setting | EB100-BT20 Exhaust air temp. 1                           |                                                                                                                                                                    |
| 40026           | Number    | -32767      | 32767      | Setting | EB100-BT21 Vented air temp. 1                            |                                                                                                                                                                    |
| 40028           | Number    | -32767      | 32767      | Setting | AZ1-BT26 Temp Collector in FLM 1                         |                                                                                                                                                                    |
| 40029           | Number    | -32767      | 32767      | Setting | AZ1-BT27 Temp Collector out FLM 1                        |                                                                                                                                                                    |
| 40030           | Number    | -32767      | 32767      | Setting | EP23-BT50 Room Temp S4                                   |                                                                                                                                                                    |
| 40031           | Number    | -32767      | 32767      | Setting | EP22-BT50 Room Temp S3                                   |                                                                                                                                                                    |
| 40032           | Number    | -32767      | 32767      | Setting | EP21-BT50 Room Temp S2                                   |                                                                                                                                                                    |
| 40033           | Number    | -32767      | 32767      | Setting | BT50 Room Temp S1                                        |                                                                                                                                                                    |
| 40042           | Number    | -32767      | 32767      | Setting | CL11-BT51 Pool 1 Temp                                    |                                                                                                                                                                    |
| 40043           | Number    | -32767      | 32767      | Setting | EP8-BT53 Solar Panel Temp                                |                                                                                                                                                                    |
| 40044           | Number    | -32767      | 32767      | Setting | EP8-BT54 Solar Load Temp                                 |                                                                                                                                                                    |
| 40045           | Number    | -32767      | 32767      | Setting | EQ1-BT64 Cool Supply Temp                                |                                                                                                                                                                    |
| 40046           | Number    | -32767      | 32767      | Setting | EQ1-BT65 Cool Return Temp                                |                                                                                                                                                                    |
| 40054           | Number    | -32767      | 32767      | Setting | EB100-FD1 Temperature limiter                            |                                                                                                                                                                    |
| 40067           | Number    | -32767      | 32767      | Setting | BT1 Average                                              |                                                                                                                                                                    |
| 40070           | Number    | -32767      | 32767      | Setting | EM1-BT52 Boiler temperature                              |                                                                                                                                                                    |
| 40071           | Number    | -32767      | 32767      | Setting | BT25 external supply temp                                |                                                                                                                                                                    |
| 40072           | Number    | -32767      | 32767      | Setting | BF1 Flow                                                 |                                                                                                                                                                    |
| 40074           | Number    | -32767      | 32767      | Setting | EB100-FR1 Anode Status                                   |                                                                                                                                                                    |
| 40079           | Number    | -2147483648 | 2147483647 | Setting | EB100-BE3 Current Phase 3                                |                                                                                                                                                                    |
| 40081           | Number    | -2147483648 | 2147483647 | Setting | EB100-BE2 Current Phase 2                                |                                                                                                                                                                    |
| 40083           | Number    | -2147483648 | 2147483647 | Setting | EB100-BE1 Current Phase 1                                |                                                                                                                                                                    |
| 40106           | Number    | -32767      | 32767      | Setting | CL12-BT51 Pool 2 Temp                                    |                                                                                                                                                                    |
| 40107           | Number    | -32767      | 32767      | Setting | EB100-BT20 Exhaust air temp. 4                           |                                                                                                                                                                    |
| 40108           | Number    | -32767      | 32767      | Setting | EB100-BT20 Exhaust air temp. 3                           |                                                                                                                                                                    |
| 40109           | Number    | -32767      | 32767      | Setting | EB100-BT20 Exhaust air temp. 2                           |                                                                                                                                                                    |
| 40110           | Number    | -32767      | 32767      | Setting | EB100-BT21 Vented air temp. 4                            |                                                                                                                                                                    |
| 40111           | Number    | -32767      | 32767      | Setting | EB100-BT21 Vented air temp. 3                            |                                                                                                                                                                    |
| 40112           | Number    | -32767      | 32767      | Setting | EB100-BT21 Vented air temp. 2                            |                                                                                                                                                                    |
| 40113           | Number    | -32767      | 32767      | Setting | AZ4-BT26 Temp Collector in FLM 4                         |                                                                                                                                                                    |
| 40114           | Number    | -32767      | 32767      | Setting | AZ3-BT26 Temp Collector in FLM 3                         |                                                                                                                                                                    |
| 40115           | Number    | -32767      | 32767      | Setting | AZ2-BT26 Temp Collector in FLM 2                         |                                                                                                                                                                    |
| 40116           | Number    | -32767      | 32767      | Setting | AZ4-BT27 Temp Collector out FLM 4                        |                                                                                                                                                                    |
| 40117           | Number    | -32767      | 32767      | Setting | AZ3-BT27 Temp Collector out FLM 3                        |                                                                                                                                                                    |
| 40118           | Number    | -32767      | 32767      | Setting | AZ2-BT27 Temp Collector out FLM 2                        |                                                                                                                                                                    |
| 40127           | Number    | -32767      | 32767      | Setting | EP23-BT3 Return temp S4                                  |                                                                                                                                                                    |
| 40128           | Number    | -32767      | 32767      | Setting | EP22-BT3 Return temp S3                                  |                                                                                                                                                                    |
| 40129           | Number    | -32767      | 32767      | Setting | EP21-BT3 Return temp S2                                  |                                                                                                                                                                    |
| 40155           | Number    | -32767      | 32767      | Setting | EQ1-BT57 Collector temp.                                 |                                                                                                                                                                    |
| 40156           | Number    | -32767      | 32767      | Setting | EQ1-BT75 Heatdump temp.                                  |                                                                                                                                                                    |
| 43001           | Number    | 0           | 65535      | Setting | Software version                                         |                                                                                                                                                                    |
| 43005           | Number    | -30000      | 30000      | Setting | Degree Minutes                                           |                                                                                                                                                                    |
| 43006           | Number    | -32767      | 32767      | Setting | Calculated Supply Temperature S4                         |                                                                                                                                                                    |
| 43007           | Number    | -32767      | 32767      | Setting | Calculated Supply Temperature S3                         |                                                                                                                                                                    |
| 43008           | Number    | -32767      | 32767      | Setting | Calculated Supply Temperature S2                         |                                                                                                                                                                    |
| 43009           | Number    | -32767      | 32767      | Setting | Calculated Supply Temperature S1                         |                                                                                                                                                                    |
| 43013           | String    | 0           | 255        | Setting | Freeze Protection Status                                 | 1=Freeze protection active                                                                                                                                         |
| 43024           | String    | 0           | 255        | Setting | Status Cooling                                           | 0=Off, 1=On                                                                                                                                                        |
| 43081           | Number    | 0           | 9999999    | Setting | Tot. op.time add.                                        |                                                                                                                                                                    |
| 43084           | Number    | -32767      | 32767      | Setting | Int. el.add. Power                                       |                                                                                                                                                                    |
| 43086           | String    | 0           | 255        | Setting | Prio                                                     | 10=Off, 20=Hot Water, 30=Heat, 40=Pool, 41=Pool 2, 50=Transfer, 60=Cooling                                                                                         |
| 43091           | Number    | 0           | 255        | Setting | Int. el.add. State                                       |                                                                                                                                                                    |
| 43097           | String    | 0           | 255        | Setting | Status of the shunt controlled additional heat accessory | 10=Off, 20=Running, 30=Passive                                                                                                                                     |
| 43103           | Number    | 0           | 255        | Setting | HPAC state                                               |                                                                                                                                                                    |
| 43108           | Number    | 0           | 255        | Setting | Fan speed current                                        |                                                                                                                                                                    |
| 43152           | Number    | 0           | 255        | Setting | Internal cooling blocked                                 |                                                                                                                                                                    |
| 43158           | Number    | 0           | 255        | Setting | External adjustment activated via input S4               |                                                                                                                                                                    |
| 43159           | Number    | 0           | 255        | Setting | External adjustment activated via input S3               |                                                                                                                                                                    |
| 43160           | Number    | 0           | 255        | Setting | External adjustment activated via input S2               |                                                                                                                                                                    |
| 43161           | Number    | 0           | 255        | Setting | External adjustment activated via input S1               |                                                                                                                                                                    |
| 43163           | String    | 0           | 255        | Setting | Blocking status of the shunt controlled add heat acc     | 0=Unblocked, 1=Blocked                                                                                                                                             |
| 43164           | Number    | 0           | 255        | Setting | Cooling blocked                                          |                                                                                                                                                                    |
| 43171           | String    | 0           | 255        | Setting | Blocking status of the step controlled add heat acc      | 0=Unblocked, 1=Blocked                                                                                                                                             |
| 43189           | String    | 0           | 255        | Setting | Ext. Heat Medium Pump                                    | 0=Off, 1=On                                                                                                                                                        |
| 43230           | Number    | 0           | 9999999    | Setting | Accumulated energy                                       |                                                                                                                                                                    |
| 43239           | Number    | 0           | 9999999    | Setting | Tot. HW op.time add.                                     |                                                                                                                                                                    |
| 43395           | Number    | 0           | 255        | Setting | HPAC Relays                                              |                                                                                                                                                                    |
| 43416           | Number    | 0           | 9999999    | Setting | Compressor starts EB100-EP14                             |                                                                                                                                                                    |
| 43420           | Number    | 0           | 9999999    | Setting | Tot. op.time compr. EB100-EP14                           |                                                                                                                                                                    |
| 43424           | Number    | 0           | 9999999    | Setting | Tot. HW op.time compr. EB100-EP14                        |                                                                                                                                                                    |
| 43427           | String    | 0           | 255        | Setting | Compressor State EP14                                    | 20=Stopped, 40=Starting, 60=Running, 100=Stopping                                                                                                                  |
| 43431           | Number    | 0           | 255        | Setting | Supply Pump State EP14                                   |                                                                                                                                                                    |
| 43433           | Number    | 0           | 255        | Setting | Brine pump state EP14                                    |                                                                                                                                                                    |
| 43435           | String    | 0           | 255        | Setting | Compressor status EP14                                   | 0=Off, 1=On                                                                                                                                                        |
| 43437           | Number    | 0           | 255        | Setting | HM-pump Status EP14                                      |                                                                                                                                                                    |
| 43439           | Number    | 0           | 255        | Setting | Brinepump Status EP14                                    |                                                                                                                                                                    |
| 43473           | Number    | 0           | 255        | Setting | Heat Compressors                                         |                                                                                                                                                                    |
| 43474           | Number    | 0           | 255        | Setting | Hot Water Compressors                                    |                                                                                                                                                                    |
| 43475           | Number    | 0           | 255        | Setting | Pool 1 Compressors                                       |                                                                                                                                                                    |
| 43484           | Number    | 0           | 255        | Setting | FLM Cooling Activated                                    |                                                                                                                                                                    |
| 43485           | Number    | 0           | 255        | Setting | FLM Cooling Activated                                    |                                                                                                                                                                    |
| 43486           | Number    | 0           | 255        | Setting | FLM Cooling Activated                                    |                                                                                                                                                                    |
| 43487           | Number    | 0           | 255        | Setting | FLM Cooling Activated                                    |                                                                                                                                                                    |
| 43514           | Number    | 0           | 255        | Setting | PCA-Base Relays EP14                                     |                                                                                                                                                                    |
| 43516           | Number    | 0           | 255        | Setting | PCA-Power Relays EP14                                    |                                                                                                                                                                    |
| 43560           | Number    | 0           | 255        | Setting | Pool 2 blocked                                           |                                                                                                                                                                    |
| 43561           | Number    | 0           | 255        | Setting | Pool 1 blocked                                           |                                                                                                                                                                    |
| 43563           | Number    | 0           | 255        | Setting | Pool 2 valve                                             |                                                                                                                                                                    |
| 43564           | Number    | 0           | 255        | Setting | Pool 1 valve                                             |                                                                                                                                                                    |
| 43577           | Number    | 0           | 255        | Setting | Pool 2 Compressors                                       |                                                                                                                                                                    |
| 43580           | Number    | 0           | 65535      | Setting | EB108 Version                                            |                                                                                                                                                                    |
| 43598           | Number    | 0           | 255        | Setting | EB108 Slave Type                                         |                                                                                                                                                                    |
| 43599           | Number    | 0           | 255        | Setting | EB108 Compressor Size                                    |                                                                                                                                                                    |
| 43600           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 43601           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43602           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43603           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 43604           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43605           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 43606           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 43607           | Number    | -32767      | 32767      | Setting | EB108-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43608           | Number    | -32767      | 32767      | Setting | EB108-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43609           | Number    | 0           | 255        | Setting | EB108-EP15 Compressor State                              |                                                                                                                                                                    |
| 43610           | Number    | 0           | 255        | Setting | EB108-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 43611           | Number    | 0           | 65535      | Setting | EB108-EP15 Relay status                                  |                                                                                                                                                                    |
| 43612           | Number    | 0           | 255        | Setting | EB108-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 43613           | Number    | 0           | 255        | Setting | EB108-EP15 Brine pump status                             |                                                                                                                                                                    |
| 43614           | Number    | 0           | 4294967295 | Setting | EB108-EP15 Compressor starts                             |                                                                                                                                                                    |
| 43616           | Number    | 0           | 4294967295 | Setting | EB108-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 43618           | Number    | 0           | 4294967295 | Setting | EB108-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43620           | Number    | 0           | 65535      | Setting | EB108-EP15 Alarm number                                  |                                                                                                                                                                    |
| 43621           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 43622           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43623           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43624           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 43625           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43626           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 43627           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 43628           | Number    | -32767      | 32767      | Setting | EB108-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43629           | Number    | -32767      | 32767      | Setting | EB108-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43630           | Number    | 0           | 255        | Setting | EB108-EP14 Compressor State                              |                                                                                                                                                                    |
| 43631           | Number    | 0           | 255        | Setting | EB108-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 43632           | Number    | 0           | 65535      | Setting | EB108-EP14 Relay status                                  |                                                                                                                                                                    |
| 43633           | Number    | 0           | 255        | Setting | EB108-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 43634           | Number    | 0           | 255        | Setting | EB108-EP14 Brine pump status                             |                                                                                                                                                                    |
| 43635           | Number    | 0           | 9999999    | Setting | EB108-EP14 Compressor starts                             |                                                                                                                                                                    |
| 43637           | Number    | 0           | 9999999    | Setting | EB108-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 43639           | Number    | 0           | 9999999    | Setting | EB108-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43641           | Number    | 0           | 65535      | Setting | EB108-EP14 Alarm number                                  |                                                                                                                                                                    |
| 43642           | Number    | 0           | 65535      | Setting | EB107 Version                                            |                                                                                                                                                                    |
| 43660           | Number    | 0           | 255        | Setting | EB107 Slave Type                                         |                                                                                                                                                                    |
| 43661           | Number    | 0           | 255        | Setting | EB107 Compressor Size                                    |                                                                                                                                                                    |
| 43662           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 43663           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43664           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43665           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 43666           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43667           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 43668           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 43669           | Number    | -32767      | 32767      | Setting | EB107-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43670           | Number    | -32767      | 32767      | Setting | EB107-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43671           | Number    | 0           | 255        | Setting | EB107-EP15 Compressor State                              |                                                                                                                                                                    |
| 43672           | Number    | 0           | 255        | Setting | EB107-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 43673           | Number    | 0           | 65535      | Setting | EB107-EP15 Relay status                                  |                                                                                                                                                                    |
| 43674           | Number    | 0           | 255        | Setting | EB107-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 43675           | Number    | 0           | 255        | Setting | EB107-EP15 Brine pump status                             |                                                                                                                                                                    |
| 43676           | Number    | 0           | 4294967295 | Setting | EB107-EP15 Compressor starts                             |                                                                                                                                                                    |
| 43678           | Number    | 0           | 4294967295 | Setting | EB107-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 43680           | Number    | 0           | 4294967295 | Setting | EB107-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43682           | Number    | 0           | 65535      | Setting | EB107-EP15 Alarm number                                  |                                                                                                                                                                    |
| 43683           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 43684           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43685           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43686           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 43687           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43688           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 43689           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 43690           | Number    | -32767      | 32767      | Setting | EB107-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43691           | Number    | -32767      | 32767      | Setting | EB107-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43692           | Number    | 0           | 255        | Setting | EB107-EP14 Compressor State                              |                                                                                                                                                                    |
| 43693           | Number    | 0           | 255        | Setting | EB107-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 43694           | Number    | 0           | 65535      | Setting | EB107-EP14 Relay status                                  |                                                                                                                                                                    |
| 43695           | Number    | 0           | 255        | Setting | EB107-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 43696           | Number    | 0           | 255        | Setting | EB107-EP14 Brine pump status                             |                                                                                                                                                                    |
| 43697           | Number    | 0           | 9999999    | Setting | EB107-EP14 Compressor starts                             |                                                                                                                                                                    |
| 43699           | Number    | 0           | 9999999    | Setting | EB107-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 43701           | Number    | 0           | 9999999    | Setting | EB107-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43703           | Number    | 0           | 65535      | Setting | EB107-EP14 Alarm number                                  |                                                                                                                                                                    |
| 43704           | Number    | 0           | 65535      | Setting | EB106 Version                                            |                                                                                                                                                                    |
| 43722           | Number    | 0           | 255        | Setting | EB106 Slave Type                                         |                                                                                                                                                                    |
| 43723           | Number    | 0           | 255        | Setting | EB106 Compressor Size                                    |                                                                                                                                                                    |
| 43724           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 43725           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43726           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43727           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 43728           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43729           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 43730           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 43731           | Number    | -32767      | 32767      | Setting | EB106-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43732           | Number    | -32767      | 32767      | Setting | EB106-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43733           | Number    | 0           | 255        | Setting | EB106-EP15 Compressor State                              |                                                                                                                                                                    |
| 43734           | Number    | 0           | 255        | Setting | EB106-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 43735           | Number    | 0           | 65535      | Setting | EB106-EP15 Relay status                                  |                                                                                                                                                                    |
| 43736           | Number    | 0           | 255        | Setting | EB106-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 43737           | Number    | 0           | 255        | Setting | EB106-EP15 Brine pump status                             |                                                                                                                                                                    |
| 43738           | Number    | 0           | 4294967295 | Setting | EB106-EP15 Compressor starts                             |                                                                                                                                                                    |
| 43740           | Number    | 0           | 4294967295 | Setting | EB106-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 43742           | Number    | 0           | 4294967295 | Setting | EB106-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43744           | Number    | 0           | 65535      | Setting | EB106-EP15 Alarm number                                  |                                                                                                                                                                    |
| 43745           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 43746           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43747           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43748           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 43749           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43750           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 43751           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 43752           | Number    | -32767      | 32767      | Setting | EB106-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43753           | Number    | -32767      | 32767      | Setting | EB106-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43754           | Number    | 0           | 255        | Setting | EB106-EP14 Compressor State                              |                                                                                                                                                                    |
| 43755           | Number    | 0           | 255        | Setting | EB106-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 43756           | Number    | 0           | 65535      | Setting | EB106-EP14 Relay status                                  |                                                                                                                                                                    |
| 43757           | Number    | 0           | 255        | Setting | EB106-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 43758           | Number    | 0           | 255        | Setting | EB106-EP14 Brine pump status                             |                                                                                                                                                                    |
| 43759           | Number    | 0           | 9999999    | Setting | EB106-EP14 Compressor starts                             |                                                                                                                                                                    |
| 43761           | Number    | 0           | 9999999    | Setting | EB106-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 43763           | Number    | 0           | 9999999    | Setting | EB106-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43765           | Number    | 0           | 65535      | Setting | EB106-EP14 Alarm number                                  |                                                                                                                                                                    |
| 43766           | Number    | 0           | 65535      | Setting | EB105 Version                                            |                                                                                                                                                                    |
| 43784           | Number    | 0           | 255        | Setting | EB105 Slave Type                                         |                                                                                                                                                                    |
| 43785           | Number    | 0           | 255        | Setting | EB105 Compressor Size                                    |                                                                                                                                                                    |
| 43786           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 43787           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43788           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43789           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 43790           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43791           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 43792           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 43793           | Number    | -32767      | 32767      | Setting | EB105-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43794           | Number    | -32767      | 32767      | Setting | EB105-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43795           | Number    | 0           | 255        | Setting | EB105-EP15 Compressor State                              |                                                                                                                                                                    |
| 43796           | Number    | 0           | 255        | Setting | EB105-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 43797           | Number    | 0           | 65535      | Setting | EB105-EP15 Relay status                                  |                                                                                                                                                                    |
| 43798           | Number    | 0           | 255        | Setting | EB105-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 43799           | Number    | 0           | 255        | Setting | EB105-EP15 Brine pump status                             |                                                                                                                                                                    |
| 43800           | Number    | 0           | 4294967295 | Setting | EB105-EP15 Compressor starts                             |                                                                                                                                                                    |
| 43802           | Number    | 0           | 4294967295 | Setting | EB105-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 43804           | Number    | 0           | 4294967295 | Setting | EB105-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43806           | Number    | 0           | 65535      | Setting | EB105-EP15 Alarm number                                  |                                                                                                                                                                    |
| 43807           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 43808           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43809           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43810           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 43811           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43812           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 43813           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 43814           | Number    | -32767      | 32767      | Setting | EB105-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43815           | Number    | -32767      | 32767      | Setting | EB105-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43816           | Number    | 0           | 255        | Setting | EB105-EP14 Compressor State                              |                                                                                                                                                                    |
| 43817           | Number    | 0           | 255        | Setting | EB105-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 43818           | Number    | 0           | 65535      | Setting | EB105-EP14 Relay status                                  |                                                                                                                                                                    |
| 43819           | Number    | 0           | 255        | Setting | EB105-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 43820           | Number    | 0           | 255        | Setting | EB105-EP14 Brine pump status                             |                                                                                                                                                                    |
| 43821           | Number    | 0           | 9999999    | Setting | EB105-EP14 Compressor starts                             |                                                                                                                                                                    |
| 43823           | Number    | 0           | 9999999    | Setting | EB105-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 43825           | Number    | 0           | 9999999    | Setting | EB105-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43827           | Number    | 0           | 65535      | Setting | EB105-EP14 Alarm number                                  |                                                                                                                                                                    |
| 43828           | Number    | 0           | 65535      | Setting | EB104 Version                                            |                                                                                                                                                                    |
| 43846           | Number    | 0           | 255        | Setting | EB104 Slave Type                                         |                                                                                                                                                                    |
| 43847           | Number    | 0           | 255        | Setting | EB104 Compressor Size                                    |                                                                                                                                                                    |
| 43848           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 43849           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43850           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43851           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 43852           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43853           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 43854           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 43855           | Number    | -32767      | 32767      | Setting | EB104-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43856           | Number    | -32767      | 32767      | Setting | EB104-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43857           | Number    | 0           | 255        | Setting | EB104-EP15 Compressor State                              |                                                                                                                                                                    |
| 43858           | Number    | 0           | 255        | Setting | EB104-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 43859           | Number    | 0           | 65535      | Setting | EB104-EP15 Relay status                                  |                                                                                                                                                                    |
| 43860           | Number    | 0           | 255        | Setting | EB104-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 43861           | Number    | 0           | 255        | Setting | EB104-EP15 Brine pump status                             |                                                                                                                                                                    |
| 43862           | Number    | 0           | 4294967295 | Setting | EB104-EP15 Compressor starts                             |                                                                                                                                                                    |
| 43864           | Number    | 0           | 4294967295 | Setting | EB104-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 43866           | Number    | 0           | 4294967295 | Setting | EB104-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43868           | Number    | 0           | 65535      | Setting | EB104-EP15 Alarm number                                  |                                                                                                                                                                    |
| 43869           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 43870           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43871           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43872           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 43873           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43874           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 43875           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 43876           | Number    | -32767      | 32767      | Setting | EB104-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43877           | Number    | -32767      | 32767      | Setting | EB104-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43878           | Number    | 0           | 255        | Setting | EB104-EP14 Compressor State                              |                                                                                                                                                                    |
| 43879           | Number    | 0           | 255        | Setting | EB104-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 43880           | Number    | 0           | 65535      | Setting | EB104-EP14 Relay status                                  |                                                                                                                                                                    |
| 43881           | Number    | 0           | 255        | Setting | EB104-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 43882           | Number    | 0           | 255        | Setting | EB104-EP14 Brine pump status                             |                                                                                                                                                                    |
| 43883           | Number    | 0           | 9999999    | Setting | EB104-EP14 Compressor starts                             |                                                                                                                                                                    |
| 43885           | Number    | 0           | 9999999    | Setting | EB104-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 43887           | Number    | 0           | 9999999    | Setting | EB104-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43889           | Number    | 0           | 65535      | Setting | EB104-EP14 Alarm number                                  |                                                                                                                                                                    |
| 43890           | Number    | 0           | 65535      | Setting | EB103 Version                                            |                                                                                                                                                                    |
| 43908           | Number    | 0           | 255        | Setting | EB103 Slave Type                                         |                                                                                                                                                                    |
| 43909           | Number    | 0           | 255        | Setting | EB103 Compressor Size                                    |                                                                                                                                                                    |
| 43910           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 43911           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43912           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43913           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 43914           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43915           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 43916           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 43917           | Number    | -32767      | 32767      | Setting | EB103-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43918           | Number    | -32767      | 32767      | Setting | EB103-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43919           | Number    | 0           | 255        | Setting | EB103-EP15 Compressor State                              |                                                                                                                                                                    |
| 43920           | Number    | 0           | 255        | Setting | EB103-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 43921           | Number    | 0           | 65535      | Setting | EB103-EP15 Relay status                                  |                                                                                                                                                                    |
| 43922           | Number    | 0           | 255        | Setting | EB103-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 43923           | Number    | 0           | 255        | Setting | EB103-EP15 Brine pump status                             |                                                                                                                                                                    |
| 43924           | Number    | 0           | 4294967295 | Setting | EB103-EP15 Compressor starts                             |                                                                                                                                                                    |
| 43926           | Number    | 0           | 4294967295 | Setting | EB103-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 43928           | Number    | 0           | 4294967295 | Setting | EB103-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43930           | Number    | 0           | 65535      | Setting | EB103-EP15 Alarm number                                  |                                                                                                                                                                    |
| 43931           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 43932           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43933           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43934           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 43935           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43936           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 43937           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 43938           | Number    | -32767      | 32767      | Setting | EB103-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43939           | Number    | -32767      | 32767      | Setting | EB103-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43940           | Number    | 0           | 255        | Setting | EB103-EP14 Compressor State                              |                                                                                                                                                                    |
| 43941           | Number    | 0           | 255        | Setting | EB103-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 43942           | Number    | 0           | 65535      | Setting | EB103-EP14 Relay status                                  |                                                                                                                                                                    |
| 43943           | Number    | 0           | 255        | Setting | EB103-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 43944           | Number    | 0           | 255        | Setting | EB103-EP14 Brine pump status                             |                                                                                                                                                                    |
| 43945           | Number    | 0           | 9999999    | Setting | EB103-EP14 Compressor starts                             |                                                                                                                                                                    |
| 43947           | Number    | 0           | 9999999    | Setting | EB103-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 43949           | Number    | 0           | 9999999    | Setting | EB103-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43951           | Number    | 0           | 65535      | Setting | EB103-EP14 Alarm number                                  |                                                                                                                                                                    |
| 43952           | Number    | 0           | 65535      | Setting | EB102 Version                                            |                                                                                                                                                                    |
| 43970           | Number    | 0           | 255        | Setting | EB102 Slave Type                                         |                                                                                                                                                                    |
| 43971           | Number    | 0           | 255        | Setting | EB102 Compressor Size                                    |                                                                                                                                                                    |
| 43972           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 43973           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43974           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43975           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 43976           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43977           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 43978           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 43979           | Number    | -32767      | 32767      | Setting | EB102-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 43980           | Number    | -32767      | 32767      | Setting | EB102-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 43981           | Number    | 0           | 255        | Setting | EB102-EP15 Compressor State                              |                                                                                                                                                                    |
| 43982           | Number    | 0           | 255        | Setting | EB102-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 43983           | Number    | 0           | 65535      | Setting | EB102-EP15 Relay status                                  |                                                                                                                                                                    |
| 43984           | Number    | 0           | 255        | Setting | EB102-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 43985           | Number    | 0           | 255        | Setting | EB102-EP15 Brine pump status                             |                                                                                                                                                                    |
| 43986           | Number    | 0           | 4294967295 | Setting | EB102-EP15 Compressor starts                             |                                                                                                                                                                    |
| 43988           | Number    | 0           | 4294967295 | Setting | EB102-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 43990           | Number    | 0           | 4294967295 | Setting | EB102-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 43992           | Number    | 0           | 65535      | Setting | EB102-EP15 Alarm number                                  |                                                                                                                                                                    |
| 43993           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 43994           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 43995           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 43996           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 43997           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 43998           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 43999           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 44000           | Number    | -32767      | 32767      | Setting | EB102-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 44001           | Number    | -32767      | 32767      | Setting | EB102-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 44002           | Number    | 0           | 255        | Setting | EB102-EP14 Compressor State                              |                                                                                                                                                                    |
| 44003           | Number    | 0           | 255        | Setting | EB102-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 44004           | Number    | 0           | 65535      | Setting | EB102-EP14 Relay status                                  |                                                                                                                                                                    |
| 44005           | Number    | 0           | 255        | Setting | EB102-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 44006           | Number    | 0           | 255        | Setting | EB102-EP14 Brine pump status                             |                                                                                                                                                                    |
| 44007           | Number    | 0           | 9999999    | Setting | EB102-EP14 Compressor starts                             |                                                                                                                                                                    |
| 44009           | Number    | 0           | 9999999    | Setting | EB102-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 44011           | Number    | 0           | 9999999    | Setting | EB102-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 44013           | Number    | 0           | 65535      | Setting | EB102-EP14 Alarm number                                  |                                                                                                                                                                    |
| 44014           | Number    | 0           | 65535      | Setting | EB101 Version                                            |                                                                                                                                                                    |
| 44032           | Number    | 0           | 255        | Setting | EB101 Slave Type                                         |                                                                                                                                                                    |
| 44033           | Number    | 0           | 255        | Setting | EB101 Compressor Size                                    |                                                                                                                                                                    |
| 44034           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT3 Return temp.                              |                                                                                                                                                                    |
| 44035           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT10 Brine in temp                            |                                                                                                                                                                    |
| 44036           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT11 Brine out temp                           |                                                                                                                                                                    |
| 44037           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT12 Cond. out                                |                                                                                                                                                                    |
| 44038           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 44039           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT15 Liquid line                              |                                                                                                                                                                    |
| 44040           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT17 Suction                                  |                                                                                                                                                                    |
| 44041           | Number    | -32767      | 32767      | Setting | EB101-EP15-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 44042           | Number    | -32767      | 32767      | Setting | EB101-EP15-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 44043           | Number    | 0           | 255        | Setting | EB101-EP15 Compressor State                              |                                                                                                                                                                    |
| 44044           | Number    | 0           | 255        | Setting | EB101-EP15 Compr. time to start                          |                                                                                                                                                                    |
| 44045           | Number    | 0           | 65535      | Setting | EB101-EP15 Relay status                                  |                                                                                                                                                                    |
| 44046           | Number    | 0           | 255        | Setting | EB101-EP15 Heat med. pump status                         |                                                                                                                                                                    |
| 44047           | Number    | 0           | 255        | Setting | EB101-EP15 Brine pump status                             |                                                                                                                                                                    |
| 44048           | Number    | 0           | 4294967295 | Setting | EB101-EP15 Compressor starts                             |                                                                                                                                                                    |
| 44050           | Number    | 0           | 4294967295 | Setting | EB101-EP15 Tot. op.time compr                            |                                                                                                                                                                    |
| 44052           | Number    | 0           | 4294967295 | Setting | EB101-EP15 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 44054           | Number    | 0           | 65535      | Setting | EB101-EP15 Alarm number                                  |                                                                                                                                                                    |
| 44055           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT3 Return temp.                              |                                                                                                                                                                    |
| 44056           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT10 Brine in temp                            |                                                                                                                                                                    |
| 44057           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT11 Brine out temp                           |                                                                                                                                                                    |
| 44058           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT12 Cond. out                                |                                                                                                                                                                    |
| 44059           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT14 Hot gas temp                             |                                                                                                                                                                    |
| 44060           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT15 Liquid line                              |                                                                                                                                                                    |
| 44061           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 44062           | Number    | -32767      | 32767      | Setting | EB101-EP14-BT29 Compr. Oil. temp.                        |                                                                                                                                                                    |
| 44063           | Number    | -32767      | 32767      | Setting | EB101-EP14-BP8 Pressure transmitter                      |                                                                                                                                                                    |
| 44064           | Number    | 0           | 255        | Setting | EB101-EP14 Compressor State                              |                                                                                                                                                                    |
| 44065           | Number    | 0           | 255        | Setting | EB101-EP14 Compr. time to start                          |                                                                                                                                                                    |
| 44066           | Number    | 0           | 65535      | Setting | EB101-EP14 Relay status                                  |                                                                                                                                                                    |
| 44067           | Number    | 0           | 255        | Setting | EB101-EP14 Heat med. pump status                         |                                                                                                                                                                    |
| 44068           | Number    | 0           | 255        | Setting | EB101-EP14 Brine pump status                             |                                                                                                                                                                    |
| 44069           | Number    | 0           | 9999999    | Setting | EB101-EP14 Compressor starts                             |                                                                                                                                                                    |
| 44071           | Number    | 0           | 9999999    | Setting | EB101-EP14 Tot. op.time compr                            |                                                                                                                                                                    |
| 44073           | Number    | 0           | 9999999    | Setting | EB101-EP14 Tot. HW op.time compr                         |                                                                                                                                                                    |
| 44075           | Number    | 0           | 65535      | Setting | EB101-EP14 Alarm number                                  |                                                                                                                                                                    |
| 44138           | String    | 0           | 255        | Setting | EB108-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44139           | String    | 0           | 255        | Setting | EB108-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44151           | String    | 0           | 255        | Setting | EB107-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44152           | String    | 0           | 255        | Setting | EB107-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44164           | String    | 0           | 255        | Setting | EB106-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44165           | String    | 0           | 255        | Setting | EB106-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44177           | String    | 0           | 255        | Setting | EB105-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44178           | String    | 0           | 255        | Setting | EB105-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44190           | String    | 0           | 255        | Setting | EB104-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44191           | String    | 0           | 255        | Setting | EB104-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44203           | String    | 0           | 255        | Setting | EB103-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44204           | String    | 0           | 255        | Setting | EB103-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44216           | String    | 0           | 255        | Setting | EB102-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44217           | String    | 0           | 255        | Setting | EB102-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44229           | String    | 0           | 255        | Setting | EB101-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44230           | String    | 0           | 255        | Setting | EB101-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44242           | String    | 0           | 255        | Setting | EB100-EP15 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44243           | String    | 0           | 255        | Setting | EB100-EP14 Prio                                          | 0=Off, 1=Heat, 2=Hot water, 3=Pool 1, 4=Pool2                                                                                                                      |
| 44266           | Number    | -30000      | 30000      | Setting | Cool Degree Minutes                                      |                                                                                                                                                                    |
| 44267           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply Temperature S4                      |                                                                                                                                                                    |
| 44268           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply Temperature S3                      |                                                                                                                                                                    |
| 44269           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply Temperature S2                      |                                                                                                                                                                    |
| 44270           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply Temperature S1                      |                                                                                                                                                                    |
| 44276           | Number    | 0           | 255        | Setting | State ACS                                                |                                                                                                                                                                    |
| 44277           | Number    | 0           | 255        | Setting | State ACS heatdump                                       |                                                                                                                                                                    |
| 44278           | Number    | 0           | 255        | Setting | State ACS cooldump                                       |                                                                                                                                                                    |
| 44282           | Number    | 0           | 255        | Setting | Used cprs. HW                                            |                                                                                                                                                                    |
| 44283           | Number    | 0           | 255        | Setting | Used cprs. heat                                          |                                                                                                                                                                    |
| 44284           | Number    | 0           | 255        | Setting | Used cprs. pool 1                                        |                                                                                                                                                                    |
| 44285           | Number    | 0           | 255        | Setting | Used cprs. pool 2                                        |                                                                                                                                                                    |
| 44298           | Number    | 0           | 9999999    | Setting | Accumulated Energy HW Cpr and Add                        |                                                                                                                                                                    |
| 44300           | Number    | 0           | 9999999    | Setting | Accumulated Energy Heat Cpr and Add                      |                                                                                                                                                                    |
| 44302           | Number    | 0           | 9999999    | Setting | Accumulated Energy Cooling Cpr                           |                                                                                                                                                                    |
| 44304           | Number    | 0           | 9999999    | Setting | Accumulated Energy Pool Cpr                              |                                                                                                                                                                    |
| 44306           | Number    | 0           | 9999999    | Setting | Accumulated Energy HW Cpr                                |                                                                                                                                                                    |
| 44308           | Number    | 0           | 9999999    | Setting | Accumulated Energy Heat Cpr                              |                                                                                                                                                                    |
| 44320           | Number    | 0           | 255        | Setting | Used cprs. cool                                          |                                                                                                                                                                    |
| 44331           | Number    | 0           | 255        | Setting | Software release                                         |                                                                                                                                                                    |
| 44380           | Number    | 0           | 255        | Setting | External Compressors                                     |                                                                                                                                                                    |
| 44410           | Number    | 0           | 255        | Setting | EB108 Own Hot Water                                      |                                                                                                                                                                    |
| 44411           | Number    | -32767      | 32767      | Setting | EB108-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44412           | Number    | -32767      | 32767      | Setting | EB108-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44413           | Number    | -32767      | 32767      | Setting | EB108-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44416           | Number    | 0           | 255        | Setting | EB107 Own Hot Water                                      |                                                                                                                                                                    |
| 44417           | Number    | -32767      | 32767      | Setting | EB107-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44418           | Number    | -32767      | 32767      | Setting | EB107-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44419           | Number    | -32767      | 32767      | Setting | EB107-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44422           | Number    | 0           | 255        | Setting | EB106 Own Hot Water                                      |                                                                                                                                                                    |
| 44423           | Number    | -32767      | 32767      | Setting | EB106-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44424           | Number    | -32767      | 32767      | Setting | EB106-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44425           | Number    | -32767      | 32767      | Setting | EB106-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44428           | Number    | 0           | 255        | Setting | EB105 Own Hot Water                                      |                                                                                                                                                                    |
| 44429           | Number    | -32767      | 32767      | Setting | EB105-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44430           | Number    | -32767      | 32767      | Setting | EB105-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44431           | Number    | -32767      | 32767      | Setting | EB105-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44434           | Number    | 0           | 255        | Setting | EB104 Own Hot Water                                      |                                                                                                                                                                    |
| 44435           | Number    | -32767      | 32767      | Setting | EB104-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44436           | Number    | -32767      | 32767      | Setting | EB104-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44437           | Number    | -32767      | 32767      | Setting | EB104-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44440           | Number    | 0           | 255        | Setting | EB103 Own Hot Water                                      |                                                                                                                                                                    |
| 44441           | Number    | -32767      | 32767      | Setting | EB103-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44442           | Number    | -32767      | 32767      | Setting | EB103-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44443           | Number    | -32767      | 32767      | Setting | EB103-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44446           | Number    | 0           | 255        | Setting | EB102 Own Hot Water                                      |                                                                                                                                                                    |
| 44447           | Number    | -32767      | 32767      | Setting | EB102-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44448           | Number    | -32767      | 32767      | Setting | EB102-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44449           | Number    | -32767      | 32767      | Setting | EB102-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44452           | Number    | 0           | 255        | Setting | EB101 Own Hot Water                                      |                                                                                                                                                                    |
| 44453           | Number    | -32767      | 32767      | Setting | EB101-BT6 Hot water load temp.                           |                                                                                                                                                                    |
| 44454           | Number    | -32767      | 32767      | Setting | EB101-BT7 Hot water top temp.                            |                                                                                                                                                                    |
| 44455           | Number    | -32767      | 32767      | Setting | EB101-BT2 Supply temp.                                   |                                                                                                                                                                    |
| 44487           | Number    | 0           | 255        | Setting | Cool Compressors                                         |                                                                                                                                                                    |
| 44744           | Number    | 0           | 255        | Setting | Extra heating system pump S4                             |                                                                                                                                                                    |
| 44745           | Number    | 0           | 255        | Setting | Extra heating system pump S3                             |                                                                                                                                                                    |
| 44746           | Number    | 0           | 255        | Setting | Extra heating system pump S2                             |                                                                                                                                                                    |
| 44748           | Number    | 0           | 255        | Setting | Pool 2 pump                                              |                                                                                                                                                                    |
| 44749           | Number    | 0           | 255        | Setting | Pool 1 pump                                              |                                                                                                                                                                    |
| 44753           | Number    | 0           | 255        | Setting | Passiv cool shunt                                        |                                                                                                                                                                    |
| 44754           | Number    | 0           | 255        | Setting | Passiv cool pool                                         |                                                                                                                                                                    |
| 44756           | Number    | 0           | 255        | Setting | State ground water pump                                  |                                                                                                                                                                    |
| 44874           | Number    | 0           | 255        | Setting | State SG Ready                                           |                                                                                                                                                                    |
| 44878           | Number    | 0           | 255        | Setting | SG Ready input A                                         |                                                                                                                                                                    |
| 44879           | Number    | 0           | 255        | Setting | SG Ready input B                                         |                                                                                                                                                                    |
| 44910           | Number    | -32767      | 32767      | Setting | Brine pump  dT act.                                      |                                                                                                                                                                    |
| 44911           | Number    | -32767      | 32767      | Setting | Brine pump  dT act.                                      |                                                                                                                                                                    |
| 44912           | Switch    | 0           | 1          | Sensor  | Brine pump auto controlled                               |                                                                                                                                                                    |
| 45001           | Number    | -32767      | 32767      | Sensor  | Alarm Number                                             |                                                                                                                                                                    |
| 47291           | Number    | 0           | 10000      | Sensor  | Floor drying timer                                       |                                                                                                                                                                    |
| 47325           | Number    | 0           | 7          | Sensor  | Step controlled add. max. step                           |                                                                                                                                                                    |
| 47004           | Number    | 0           | 15         | Sensor  | Heat curve S4                                            |                                                                                                                                                                    |
| 47005           | Number    | 0           | 15         | Sensor  | Heat curve S3                                            |                                                                                                                                                                    |
| 47006           | Number    | 0           | 15         | Sensor  | Heat curve S2                                            |                                                                                                                                                                    |
| 47007           | Number    | 0           | 15         | Sensor  | Heat curve S1                                            |                                                                                                                                                                    |
| 47008           | Number    | -10         | 10         | Sensor  | Offset S4                                                |                                                                                                                                                                    |
| 47009           | Number    | -10         | 10         | Sensor  | Offset S3                                                |                                                                                                                                                                    |
| 47010           | Number    | -10         | 10         | Sensor  | Offset S2                                                |                                                                                                                                                                    |
| 47011           | Number    | -10         | 10         | Sensor  | Offset S1                                                |                                                                                                                                                                    |
| 47012           | Number    | 50          | 700        | Sensor  | Min Supply System 4                                      |                                                                                                                                                                    |
| 47013           | Number    | 50          | 700        | Sensor  | Min Supply System 3                                      |                                                                                                                                                                    |
| 47014           | Number    | 50          | 700        | Sensor  | Min Supply System 2                                      |                                                                                                                                                                    |
| 47015           | Number    | 50          | 700        | Sensor  | Min Supply System 1                                      |                                                                                                                                                                    |
| 47016           | Number    | 50          | 700        | Sensor  | Max Supply System 4                                      |                                                                                                                                                                    |
| 47017           | Number    | 50          | 700        | Sensor  | Max Supply System 3                                      |                                                                                                                                                                    |
| 47018           | Number    | 50          | 700        | Sensor  | Max Supply System 2                                      |                                                                                                                                                                    |
| 47019           | Number    | 50          | 700        | Sensor  | Max Supply System 1                                      |                                                                                                                                                                    |
| 47020           | Number    | 0           | 80         | Sensor  | Own Curve P7                                             |                                                                                                                                                                    |
| 47021           | Number    | 0           | 80         | Sensor  | Own Curve P6                                             |                                                                                                                                                                    |
| 47022           | Number    | 0           | 80         | Sensor  | Own Curve P5                                             |                                                                                                                                                                    |
| 47023           | Number    | 0           | 80         | Sensor  | Own Curve P4                                             |                                                                                                                                                                    |
| 47024           | Number    | 0           | 80         | Sensor  | Own Curve P3                                             |                                                                                                                                                                    |
| 47025           | Number    | 0           | 80         | Sensor  | Own Curve P2                                             |                                                                                                                                                                    |
| 47026           | Number    | 0           | 80         | Sensor  | Own Curve P1                                             |                                                                                                                                                                    |
| 47027           | Number    | -40         | 30         | Sensor  | Point offset outdoor temp.                               |                                                                                                                                                                    |
| 47028           | Number    | -10         | 10         | Sensor  | Point offset                                             |                                                                                                                                                                    |
| 47029           | Number    | -10         | 10         | Sensor  | External adjustment S4                                   |                                                                                                                                                                    |
| 47030           | Number    | -10         | 10         | Sensor  | External adjustment S3                                   |                                                                                                                                                                    |
| 47031           | Number    | -10         | 10         | Sensor  | External adjustment S2                                   |                                                                                                                                                                    |
| 47032           | Number    | -10         | 10         | Sensor  | External adjustment S1                                   |                                                                                                                                                                    |
| 47033           | Number    | 50          | 300        | Sensor  | External adjustment with room sensor S4                  |                                                                                                                                                                    |
| 47034           | Number    | 50          | 300        | Sensor  | External adjustment with room sensor S3                  |                                                                                                                                                                    |
| 47035           | Number    | 50          | 300        | Sensor  | External adjustment with room sensor S2                  |                                                                                                                                                                    |
| 47036           | Number    | 50          | 300        | Sensor  | External adjustment with room sensor S1                  |                                                                                                                                                                    |
| 47041           | String    | 0           | 2          | Sensor  | Hot water mode                                           | 0=Economy, 1=Normal, 2=Luxury                                                                                                                                      |
| 47043           | Number    | 50          | 700        | Sensor  | Start temperature HW Luxury                              |                                                                                                                                                                    |
| 47044           | Number    | 50          | 700        | Sensor  | Start temperature HW Normal                              |                                                                                                                                                                    |
| 47045           | Number    | 50          | 700        | Sensor  | Start temperature HW Economy                             |                                                                                                                                                                    |
| 47046           | Number    | 550         | 700        | Sensor  | Stop temperature Periodic HW                             |                                                                                                                                                                    |
| 47047           | Number    | 50          | 700        | Sensor  | Stop temperature HW Luxury                               |                                                                                                                                                                    |
| 47048           | Number    | 50          | 700        | Sensor  | Stop temperature HW Normal                               |                                                                                                                                                                    |
| 47049           | Number    | 50          | 700        | Sensor  | Stop temperature HW Economy                              |                                                                                                                                                                    |
| 47050           | Switch    | 0           | 1          | Setting | Periodic HW                                              |                                                                                                                                                                    |
| 47051           | Number    | 1           | 90         | Setting | Periodic HW Interval                                     |                                                                                                                                                                    |
| 47054           | Number    | 1           | 60         | Setting | Run time HWC                                             |                                                                                                                                                                    |
| 47055           | Number    | 0           | 60         | Setting | Still time HWC                                           |                                                                                                                                                                    |
| 47131           | String    | 0           | 21         | Setting | Language                                                 | 0=English, 1=Svenska, 2=Deutsch, 3=Francais, 4=Espanol, 5=Suomi, 6=Lietuviu, 7=Cesky, 8=Polski, 9=Nederlands, 10=Norsk, 11=Dansk, 12=Eesti, 13=Latviesu, 16=Magyar |
| 47134           | Number    | 0           | 180        | Setting | Period HW                                                |                                                                                                                                                                    |
| 47135           | Number    | 0           | 180        | Setting | Period Heat                                              |                                                                                                                                                                    |
| 47136           | Number    | 0           | 180        | Setting | Period Pool                                              |                                                                                                                                                                    |
| 47138           | String    | 10          | 40         | Setting | Operational mode heat medium pump                        | 10=Intermittent, 20=Continous, 30=Economy, 40=Auto                                                                                                                 |
| 47139           | String    | 10          | 30         | Setting | Operational mode brine medium pump                       | 10=Intermittent, 20=Continuous, 30=Economy, 40=Auto                                                                                                                |
| 47206           | Number    | -1000       | -30        | Setting | DM start heating                                         |                                                                                                                                                                    |
| 47207           | Number    | -32767      | 32767      | Setting | DM start cooling                                         |                                                                                                                                                                    |
| 47208           | Number    | -32767      | 32767      | Setting | DM start add.                                            |                                                                                                                                                                    |
| 47209           | Number    | -32767      | 32767      | Setting | DM between add. steps                                    |                                                                                                                                                                    |
| 47210           | Number    | -2000       | -30        | Setting | DM start add. with shunt                                 |                                                                                                                                                                    |
| 47212           | Number    | 0           | 4500       | Setting | Max int add. power                                       |                                                                                                                                                                    |
| 47214           | Number    | 1           | 200        | Setting | Fuse                                                     |                                                                                                                                                                    |
| 47261           | Number    | 0           | 100        | Setting | Exhaust Fan speed 4                                      |                                                                                                                                                                    |
| 47262           | Number    | 0           | 100        | Setting | Exhaust Fan speed 3                                      |                                                                                                                                                                    |
| 47263           | Number    | 0           | 100        | Setting | Exhaust Fan speed 2                                      |                                                                                                                                                                    |
| 47264           | Number    | 0           | 100        | Setting | Exhaust Fan speed 1                                      |                                                                                                                                                                    |
| 47265           | Number    | 0           | 100        | Setting | Exhaust Fan speed normal                                 |                                                                                                                                                                    |
| 47271           | Number    | 1           | 99         | Setting | Fan return time 4                                        |                                                                                                                                                                    |
| 47272           | Number    | 1           | 99         | Setting | Fan return time 3                                        |                                                                                                                                                                    |
| 47273           | Number    | 1           | 99         | Setting | Fan return time 2                                        |                                                                                                                                                                    |
| 47274           | Number    | 1           | 99         | Setting | Fan return time 1                                        |                                                                                                                                                                    |
| 47275           | Number    | 1           | 24         | Setting | Filter Reminder period                                   |                                                                                                                                                                    |
| 47276           | Switch    | 0           | 1          | Setting | Floor drying                                             |                                                                                                                                                                    |
| 47277           | Number    | 0           | 30         | Setting | Floor drying period 7                                    |                                                                                                                                                                    |
| 47278           | Number    | 0           | 30         | Setting | Floor drying period 6                                    |                                                                                                                                                                    |
| 47279           | Number    | 0           | 30         | Setting | Floor drying period 5                                    |                                                                                                                                                                    |
| 47280           | Number    | 0           | 30         | Setting | Floor drying period 4                                    |                                                                                                                                                                    |
| 47281           | Number    | 0           | 30         | Setting | Floor drying period 3                                    |                                                                                                                                                                    |
| 47282           | Number    | 0           | 30         | Setting | Floor drying period 2                                    |                                                                                                                                                                    |
| 47283           | Number    | 0           | 30         | Setting | Floor drying period 1                                    |                                                                                                                                                                    |
| 47284           | Number    | 15          | 70         | Setting | Floor drying temp. 7                                     |                                                                                                                                                                    |
| 47285           | Number    | 15          | 70         | Setting | Floor drying temp. 6                                     |                                                                                                                                                                    |
| 47286           | Number    | 15          | 70         | Setting | Floor drying temp. 5                                     |                                                                                                                                                                    |
| 47287           | Number    | 15          | 70         | Setting | Floor drying temp. 4                                     |                                                                                                                                                                    |
| 47288           | Number    | 15          | 70         | Setting | Floor drying temp. 3                                     |                                                                                                                                                                    |
| 47289           | Number    | 15          | 70         | Setting | Floor drying temp. 2                                     |                                                                                                                                                                    |
| 47290           | Number    | 15          | 70         | Setting | Floor drying temp. 1                                     |                                                                                                                                                                    |
| 47302           | Switch    | 0           | 1          | Setting | Climate system 2 accessory                               |                                                                                                                                                                    |
| 47303           | Switch    | 0           | 1          | Setting | Climate system 3 accessory                               |                                                                                                                                                                    |
| 47304           | Switch    | 0           | 1          | Setting | Climate system 4 accessory                               |                                                                                                                                                                    |
| 47305           | Number    | 1           | 100        | Setting | Climate system 4 mixing valve amp.                       |                                                                                                                                                                    |
| 47306           | Number    | 1           | 100        | Setting | Climate system 3 mixing valve amp.                       |                                                                                                                                                                    |
| 47307           | Number    | 1           | 100        | Setting | Climate system 2 mixing valve amp.                       |                                                                                                                                                                    |
| 47308           | Number    | 10          | 300        | Setting | Climate system 4 shunt wait                              |                                                                                                                                                                    |
| 47309           | Number    | 10          | 300        | Setting | Climate system 3 shunt wait                              |                                                                                                                                                                    |
| 47310           | Number    | 10          | 300        | Setting | Climate system 2 shunt wait                              |                                                                                                                                                                    |
| 47312           | Switch    | 0           | 1          | Setting | FLM pump                                                 |                                                                                                                                                                    |
| 47313           | Number    | 1           | 30         | Setting | FLM defrost                                              |                                                                                                                                                                    |
| 47317           | Switch    | 0           | 1          | Setting | Shunt controlled add. accessory                          |                                                                                                                                                                    |
| 47318           | Number    | 5           | 90         | Setting | Shunt controlled add. min. temp.                         |                                                                                                                                                                    |
| 47319           | Number    | 0           | 48         | Setting | Shunt controlled add. min. runtime                       |                                                                                                                                                                    |
| 47320           | Number    | 1           | 100        | Setting | Shunt controlled add. mixing valve amp.                  |                                                                                                                                                                    |
| 47321           | Number    | 10          | 300        | Setting | Shunt controlled add. mixing valve wait                  |                                                                                                                                                                    |
| 47322           | Switch    | 0           | 1          | Setting | Step controlled add. accessory                           |                                                                                                                                                                    |
| 47323           | Number    | -2000       | -30        | Setting | Step controlled add. start DM                            |                                                                                                                                                                    |
| 47324           | Number    | 0           | 1000       | Setting | Step controlled add. diff. DM                            |                                                                                                                                                                    |
| 47326           | Switch    | 0           | 1          | Setting | Step controlled add. mode                                |                                                                                                                                                                    |
| 47327           | Switch    | 0           | 1          | Setting | Ground water pump accessory                              |                                                                                                                                                                    |
| 47329           | Switch    | 0           | 1          | Setting | Cooling 2-pipe accessory                                 |                                                                                                                                                                    |
| 47330           | Switch    | 0           | 1          | Setting | Cooling 4-pipe accessory                                 |                                                                                                                                                                    |
| 47335           | Number    | 0           | 48         | Setting | Time betw. switch heat/cool                              |                                                                                                                                                                    |
| 47336           | Number    | 5           | 100        | Setting | Heat at room under temp.                                 |                                                                                                                                                                    |
| 47337           | Number    | 5           | 100        | Setting | Cool at room over temp.                                  |                                                                                                                                                                    |
| 47338           | Number    | 1           | 100        | Setting | Cooling mix. valve amp.                                  |                                                                                                                                                                    |
| 47339           | Number    | 10          | 300        | Setting | Cooling mix. valve step delay                            |                                                                                                                                                                    |
| 47340           | Switch    | 0           | 1          | Setting | Cooling with room sensor                                 |                                                                                                                                                                    |
| 47341           | Switch    | 0           | 1          | Setting | HPAC accessory                                           |                                                                                                                                                                    |
| 47342           | Number    | 10          | 500        | Setting | Start Passive Cooling DM                                 |                                                                                                                                                                    |
| 47343           | Number    | 30          | 300        | Setting | Start Active Cooling DM                                  |                                                                                                                                                                    |
| 47352           | Switch    | 0           | 1          | Setting | SMS40 accessory                                          |                                                                                                                                                                    |
| 47365           | Switch    | 0           | 1          | Setting | RMU System 1                                             |                                                                                                                                                                    |
| 47366           | Switch    | 0           | 1          | Setting | RMU System 2                                             |                                                                                                                                                                    |
| 47367           | Switch    | 0           | 1          | Setting | RMU System 3                                             |                                                                                                                                                                    |
| 47368           | Switch    | 0           | 1          | Setting | RMU System 4                                             |                                                                                                                                                                    |
| 47370           | Switch    | 0           | 1          | Setting | Allow Additive Heating                                   |                                                                                                                                                                    |
| 47371           | Switch    | 0           | 1          | Setting | Allow Heating                                            |                                                                                                                                                                    |
| 47372           | Switch    | 0           | 1          | Setting | Allow Cooling                                            |                                                                                                                                                                    |
| 47378           | Number    | 10          | 250        | Setting | Max diff. comp.                                          |                                                                                                                                                                    |
| 47379           | Number    | 10          | 240        | Setting | Max diff. add.                                           |                                                                                                                                                                    |
| 47380           | Switch    | 0           | 1          | Setting | Low brine out autoreset                                  |                                                                                                                                                                    |
| 47381           | Number    | -120        | 150        | Setting | Low brine out temp.                                      |                                                                                                                                                                    |
| 47382           | Switch    | 0           | 1          | Setting | High brine in                                            |                                                                                                                                                                    |
| 47383           | Number    | 100         | 300        | Setting | High brine in temp.                                      |                                                                                                                                                                    |
| 47384           | String    | 1           | 2          | Setting | Date format                                              | 1=DD-MM-YY, 2=YY-MM-DD                                                                                                                                             |
| 47385           | String    | 12          | 24         | Setting | Time format                                              | 12=hours 24, 24=Hours                                                                                                                                              |
| 47387           | Switch    | 0           | 1          | Setting | HW production                                            | 12=hours 24, 24=Hours                                                                                                                                              |
| 47388           | Switch    | 0           | 1          | Setting | Alarm lower room temp.                                   | 12=hours 24, 24=Hours                                                                                                                                              |
| 47389           | Switch    | 0           | 1          | Setting | Alarm lower HW temp.                                     | 12=hours 24, 24=Hours                                                                                                                                              |
| 47391           | Switch    | 0           | 1          | Setting | Use room sensor S4                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47392           | Switch    | 0           | 1          | Setting | Use room sensor S3                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47393           | Switch    | 0           | 1          | Setting | Use room sensor S2                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47394           | Switch    | 0           | 1          | Setting | Use room sensor S1                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47395           | Number    | 50          | 300        | Setting | Room sensor setpoint S4                                  |                                                                                                                                                                    |
| 47396           | Number    | 50          | 300        | Setting | Room sensor setpoint S3                                  |                                                                                                                                                                    |
| 47397           | Number    | 50          | 300        | Setting | Room sensor setpoint S2                                  |                                                                                                                                                                    |
| 47398           | Number    | 50          | 300        | Setting | Room sensor setpoint S1                                  |                                                                                                                                                                    |
| 47399           | Number    | 0           | 60         | Setting | Room sensor factor S4                                    |                                                                                                                                                                    |
| 47400           | Number    | 0           | 60         | Setting | Room sensor factor S3                                    |                                                                                                                                                                    |
| 47401           | Number    | 0           | 60         | Setting | Room sensor factor S2                                    |                                                                                                                                                                    |
| 47402           | Number    | 0           | 60         | Setting | Room sensor factor S1                                    |                                                                                                                                                                    |
| 47413           | Number    | 1           | 100        | Setting | Speed circ.pump HW                                       |                                                                                                                                                                    |
| 47414           | Number    | 1           | 100        | Setting | Speed circ.pump Heat                                     |                                                                                                                                                                    |
| 47415           | Number    | 70          | 70         | Setting | Speed circ.pump Pool                                     |                                                                                                                                                                    |
| 47416           | Number    | 0           | 255        | Setting | Speed circ.pump Economy                                  |                                                                                                                                                                    |
| 47417           | Number    | 1           | 100        | Setting | Speed circ.pump Cooling                                  |                                                                                                                                                                    |
| 47418           | Number    | 1           | 100        | Setting | Speed brine pump                                         |                                                                                                                                                                    |
| 47537           | Switch    | 0           | 1          | Setting | Night cooling                                            |                                                                                                                                                                    |
| 47538           | Number    | 20          | 30         | Setting | Start room temp. night cooling                           |                                                                                                                                                                    |
| 47539           | Number    | 3           | 10         | Setting | Night Cooling Min. diff.                                 |                                                                                                                                                                    |
| 47540           | Number    | 10          | 2000       | Setting | Heat DM diff                                             |                                                                                                                                                                    |
| 47543           | Number    | 10          | 150        | Setting | Cooling DM diff                                          |                                                                                                                                                                    |
| 47570           | String    | 0           | 255        | Setting | Operational mode                                         | 0=Auto, 1=Manual, 2=Add. heat only                                                                                                                                 |
| 48053           | Number    | 0           | 100        | Setting | FLM 2 speed 4                                            |                                                                                                                                                                    |
| 48054           | Number    | 0           | 100        | Setting | FLM 2 speed 3                                            |                                                                                                                                                                    |
| 48055           | Number    | 0           | 100        | Setting | FLM 2 speed 2                                            |                                                                                                                                                                    |
| 48056           | Number    | 0           | 100        | Setting | FLM 2 speed 1                                            |                                                                                                                                                                    |
| 48057           | Number    | 0           | 100        | Setting | FLM 2 speed normal                                       |                                                                                                                                                                    |
| 48058           | Number    | 0           | 100        | Setting | FLM 3 speed 4                                            |                                                                                                                                                                    |
| 48059           | Number    | 0           | 100        | Setting | FLM 3 speed 3                                            |                                                                                                                                                                    |
| 48060           | Number    | 0           | 100        | Setting | FLM 3 speed 2                                            |                                                                                                                                                                    |
| 48061           | Number    | 0           | 100        | Setting | FLM 3 speed 1                                            |                                                                                                                                                                    |
| 48062           | Number    | 0           | 100        | Setting | FLM 3 speed normal                                       |                                                                                                                                                                    |
| 48063           | Number    | 0           | 100        | Setting | FLM 4 speed 4                                            |                                                                                                                                                                    |
| 48064           | Number    | 0           | 100        | Setting | FLM 4 speed 3                                            |                                                                                                                                                                    |
| 48065           | Number    | 0           | 100        | Setting | FLM 4 speed 2                                            |                                                                                                                                                                    |
| 48066           | Number    | 0           | 100        | Setting | FLM 4 speed 1                                            |                                                                                                                                                                    |
| 48067           | Number    | 0           | 100        | Setting | FLM 4 speed normal                                       |                                                                                                                                                                    |
| 48068           | Switch    | 0           | 1          | Setting | FLM 4 accessory                                          |                                                                                                                                                                    |
| 48069           | Switch    | 0           | 1          | Setting | FLM 3 accessory                                          |                                                                                                                                                                    |
| 48070           | Switch    | 0           | 1          | Setting | FLM 2 accessory                                          |                                                                                                                                                                    |
| 48071           | Switch    | 0           | 1          | Setting | FLM 1 accessory                                          |                                                                                                                                                                    |
| 48072           | Number    | -32767      | 32767      | Setting | DM diff start add.                                       |                                                                                                                                                                    |
| 48073           | Switch    | 0           | 1          | Setting | FLM cooling                                              |                                                                                                                                                                    |
| 48074           | Number    | 50          | 400        | Setting | Set point for BT74                                       |                                                                                                                                                                    |
| 48087           | Switch    | 0           | 1          | Setting | Pool 2 accessory                                         |                                                                                                                                                                    |
| 48088           | Switch    | 0           | 1          | Setting | Pool 1 accessory                                         |                                                                                                                                                                    |
| 48089           | Number    | 50          | 800        | Setting | Pool 2 start temp.                                       |                                                                                                                                                                    |
| 48090           | Number    | 50          | 800        | Setting | Pool 1 start temp.                                       |                                                                                                                                                                    |
| 48091           | Number    | 50          | 800        | Setting | Pool 2 stop temp.                                        |                                                                                                                                                                    |
| 48092           | Number    | 50          | 800        | Setting | Pool 1 stop temp.                                        |                                                                                                                                                                    |
| 48093           | Switch    | 0           | 1          | Setting | Pool 2 Activated                                         |                                                                                                                                                                    |
| 48094           | Switch    | 0           | 1          | Setting | Pool 1 Activated                                         |                                                                                                                                                                    |
| 48133           | Number    | 0           | 180        | Setting | Period Pool 2                                            |                                                                                                                                                                    |
| 48174           | Number    | 5           | 30         | Setting | Min cooling supply temp S4                               |                                                                                                                                                                    |
| 48175           | Number    | 5           | 30         | Setting | Min cooling supply temp S3                               |                                                                                                                                                                    |
| 48176           | Number    | 5           | 30         | Setting | Min cooling supply temp S2                               |                                                                                                                                                                    |
| 48177           | Number    | 5           | 30         | Setting | Min cooling supply temp S1                               |                                                                                                                                                                    |
| 48178           | Number    | 5           | 30         | Setting | Cooling supply temp. at 20°C                             |                                                                                                                                                                    |
| 48179           | Number    | 5           | 30         | Setting | Cooling supply temp. at 20°C                             |                                                                                                                                                                    |
| 48180           | Number    | 5           | 30         | Setting | Cooling supply temp. at 20°C                             |                                                                                                                                                                    |
| 48181           | Number    | 5           | 30         | Setting | Cooling supply temp. at 20°C                             |                                                                                                                                                                    |
| 48182           | Number    | 5           | 30         | Setting | Cooling supply temp. at 40°C                             |                                                                                                                                                                    |
| 48183           | Number    | 5           | 30         | Setting | Cooling supply temp. at 40°C                             |                                                                                                                                                                    |
| 48184           | Number    | 5           | 30         | Setting | Cooling supply temp. at 40°C                             |                                                                                                                                                                    |
| 48185           | Number    | 5           | 30         | Setting | Cooling supply temp. at 40°C                             |                                                                                                                                                                    |
| 48186           | Switch    | 0           | 1          | Setting | Cooling use mix. valves                                  |                                                                                                                                                                    |
| 48187           | Switch    | 0           | 1          | Setting | Cooling use mix. valves                                  |                                                                                                                                                                    |
| 48188           | Switch    | 0           | 1          | Setting | Cooling use mix. valves                                  |                                                                                                                                                                    |
| 48189           | Number    | 0           | 255        | Setting | Cooling use mix. valves                                  |                                                                                                                                                                    |
| 48190           | Number    | 10          | 500        | Setting | Heatdump mix. valve delay                                |                                                                                                                                                                    |
| 48191           | Number    | 1           | 100        | Setting | Heatdump mix. valve amp.                                 |                                                                                                                                                                    |
| 48192           | Number    | 10          | 500        | Setting | Cooldump mix. valve delay                                |                                                                                                                                                                    |
| 48193           | Number    | 1           | 100        | Setting | Cooldump mix. valve amp.                                 |                                                                                                                                                                    |
| 48194           | Switch    | 0           | 1          | Setting | ACS accessory                                            |                                                                                                                                                                    |
| 48195           | Switch    | 0           | 1          | Setting | ACS heat dump 24h-function                               |                                                                                                                                                                    |
| 48196           | Switch    | 0           | 1          | Setting | ACS run brinepump in wait mode                           |                                                                                                                                                                    |
| 48197           | Number    | 0           | 100        | Setting | ACS closingtime for cool dump                            |                                                                                                                                                                    |
| 48226           | Number    | 80          | 100        | Setting | Max charge pump reg speed                                |                                                                                                                                                                    |
| 48282           | Switch    | 0           | 1          | Setting | SG Ready heating                                         |                                                                                                                                                                    |
| 48283           | Switch    | 0           | 1          | Setting | SG Ready cooling                                         |                                                                                                                                                                    |
| 48284           | Switch    | 0           | 1          | Setting | SG Ready hot water                                       |                                                                                                                                                                    |
| 48285           | Switch    | 0           | 1          | Setting | SG Ready pool                                            |                                                                                                                                                                    |
| 48452           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, hw                          |                                                                                                                                                                    |
| 48453           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, heat                        |                                                                                                                                                                    |
| 48454           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, pool                        |                                                                                                                                                                    |
| 48455           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, cool                        |                                                                                                                                                                    |
| 48456           | Number    | 10          | 20         | Setting | Operational mode heat medium pump, cooling               |                                                                                                                                                                    |
| 48458           | Number    | 50          | 100        | Setting | Max speed circ.pump Heat                                 |                                                                                                                                                                    |
| 48459           | Number    | 0           | 100        | Setting | Speed brine pump cooling                                 |                                                                                                                                                                    |
| 48487           | Number    | 1           | 100        | Setting | Speed circ.pump Cooling                                  |                                                                                                                                                                    |

### F1x55

This binding currently supports following channels for F1x55 pump models:

| Channel Type ID | Item Type | Min         | Max        | Type    | Description                                              | Values                                                                                                                                                             |
|-----------------|-----------|-------------|------------|---------|----------------------------------------------------------|--------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| 32260           | Number    | 0           | 255        | Setting | NIBE Inverter 216-state                                  |                                                                                                                                                                    |
| 40004           | Number    | -32767      | 32767      | Setting | BT1 Outdoor Temperature                                  |                                                                                                                                                                    |
| 40005           | Number    | -32767      | 32767      | Setting | EP23-BT2 Supply temp S4                                  |                                                                                                                                                                    |
| 40006           | Number    | -32767      | 32767      | Setting | EP22-BT2 Supply temp S3                                  |                                                                                                                                                                    |
| 40007           | Number    | -32767      | 32767      | Setting | EP21-BT2 Supply temp S2                                  |                                                                                                                                                                    |
| 40008           | Number    | -32767      | 32767      | Setting | BT2 Supply temp S1                                       |                                                                                                                                                                    |
| 40012           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT3 Return temp                               |                                                                                                                                                                    |
| 40013           | Number    | -32767      | 32767      | Setting | BT7 HW Top                                               |                                                                                                                                                                    |
| 40014           | Number    | -32767      | 32767      | Setting | BT6 HW Load                                              |                                                                                                                                                                    |
| 40015           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT10 Brine In Temp                            |                                                                                                                                                                    |
| 40016           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT11 Brine Out Temp                           |                                                                                                                                                                    |
| 40017           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT12 Condensor Out                            |                                                                                                                                                                    |
| 40018           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT14 Hot Gas Temp                             |                                                                                                                                                                    |
| 40019           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT15 Liquid Line                              |                                                                                                                                                                    |
| 40022           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT17 Suction                                  |                                                                                                                                                                    |
| 40025           | Number    | -32767      | 32767      | Setting | BT20 Exhaust air temp. 1                                 |                                                                                                                                                                    |
| 40026           | Number    | -32767      | 32767      | Setting | BT21 Vented air temp. 1                                  |                                                                                                                                                                    |
| 40028           | Number    | -32767      | 32767      | Setting | AZ1-BT26 Temp Collector in FLM 1                         |                                                                                                                                                                    |
| 40029           | Number    | -32767      | 32767      | Setting | AZ1-BT27 Temp Collector out FLM 1                        |                                                                                                                                                                    |
| 40030           | Number    | -32767      | 32767      | Setting | EP23-BT50 Room Temp S4                                   |                                                                                                                                                                    |
| 40031           | Number    | -32767      | 32767      | Setting | EP22-BT50 Room Temp S3                                   |                                                                                                                                                                    |
| 40032           | Number    | -32767      | 32767      | Setting | EP21-BT50 Room Temp S2                                   |                                                                                                                                                                    |
| 40033           | Number    | -32767      | 32767      | Setting | BT50 Room Temp S1                                        |                                                                                                                                                                    |
| 40042           | Number    | -32767      | 32767      | Setting | CL11-BT51 Pool 1 Temp                                    |                                                                                                                                                                    |
| 40043           | Number    | -32767      | 32767      | Setting | BT53 Solar Panel Temp                                    |                                                                                                                                                                    |
| 40044           | Number    | -32767      | 32767      | Setting | BT54 Solar Load Temp                                     |                                                                                                                                                                    |
| 40045           | Number    | -32767      | 32767      | Setting | EQ1-BT64 Cool Supply Temp                                |                                                                                                                                                                    |
| 40046           | Number    | -32767      | 32767      | Setting | EQ1-BT65 Cool Return Temp                                |                                                                                                                                                                    |
| 40054           | Number    | -32767      | 32767      | Setting | EB100-FD1 Temperature limiter                            |                                                                                                                                                                    |
| 40067           | Number    | -32767      | 32767      | Setting | BT1 Average                                              |                                                                                                                                                                    |
| 40070           | Number    | -32767      | 32767      | Setting | EM1-BT52 Boiler Temperature                              |                                                                                                                                                                    |
| 40071           | Number    | -32767      | 32767      | Setting | BT25 Ext. Supply                                         |                                                                                                                                                                    |
| 40072           | Number    | -32767      | 32767      | Setting | BF1 EP14 Flow                                            |                                                                                                                                                                    |
| 40074           | Number    | -32767      | 32767      | Setting | EB100-FR1 Anode Status                                   |                                                                                                                                                                    |
| 40075           | Number    | -32767      | 32767      | Setting | BT22 Supply air temp.                                    |                                                                                                                                                                    |
| 40079           | Number    | 0           | 4294967295 | Setting | EB100-BE3 Current                                        |                                                                                                                                                                    |
| 40081           | Number    | 0           | 4294967295 | Setting | EB100-BE2 Current                                        |                                                                                                                                                                    |
| 40083           | Number    | 0           | 4294967295 | Setting | EB100-BE1 Current                                        |                                                                                                                                                                    |
| 40106           | Number    | -32767      | 32767      | Setting | CL12-BT51 Pool 2 Temp                                    |                                                                                                                                                                    |
| 40107           | Number    | -32767      | 32767      | Setting | BT20 Exhaust air temp. 4                                 |                                                                                                                                                                    |
| 40108           | Number    | -32767      | 32767      | Setting | BT20 Exhaust air temp. 3                                 |                                                                                                                                                                    |
| 40109           | Number    | -32767      | 32767      | Setting | BT20 Exhaust air temp. 2                                 |                                                                                                                                                                    |
| 40110           | Number    | -32767      | 32767      | Setting | BT21 Vented air temp. 4                                  |                                                                                                                                                                    |
| 40111           | Number    | -32767      | 32767      | Setting | BT21 Vented air temp. 3                                  |                                                                                                                                                                    |
| 40112           | Number    | -32767      | 32767      | Setting | BT21 Vented air temp. 2                                  |                                                                                                                                                                    |
| 40113           | Number    | -32767      | 32767      | Setting | AZ4-BT26 Temp Collector in FLM 4                         |                                                                                                                                                                    |
| 40114           | Number    | -32767      | 32767      | Setting | AZ3-BT26 Temp Collector in FLM 3                         |                                                                                                                                                                    |
| 40115           | Number    | -32767      | 32767      | Setting | AZ2-BT26 Temp Collector in FLM 2                         |                                                                                                                                                                    |
| 40116           | Number    | -32767      | 32767      | Setting | AZ4-BT27 Temp Collector out FLM 4                        |                                                                                                                                                                    |
| 40117           | Number    | -32767      | 32767      | Setting | AZ3-BT27 Temp Collector out FLM 3                        |                                                                                                                                                                    |
| 40118           | Number    | -32767      | 32767      | Setting | AZ2-BT27 Temp Collector out FLM 2                        |                                                                                                                                                                    |
| 40127           | Number    | -32767      | 32767      | Setting | EP23-BT3 Return temp S4                                  |                                                                                                                                                                    |
| 40128           | Number    | -32767      | 32767      | Setting | EP22-BT3 Return temp S3                                  |                                                                                                                                                                    |
| 40129           | Number    | -32767      | 32767      | Setting | EP21-BT3 Return temp S2                                  |                                                                                                                                                                    |
| 40146           | Number    | -32767      | 32767      | Setting | EB100-EP14-BT29 Cpr Oil Temp                             |                                                                                                                                                                    |
| 40147           | Number    | -32767      | 32767      | Setting | BT70 HW Comfort Supply Temp.                             |                                                                                                                                                                    |
| 40155           | Number    | -32767      | 32767      | Setting | EQ1-BT57 Collector Temp.                                 |                                                                                                                                                                    |
| 40156           | Number    | -32767      | 32767      | Setting | EQ1-BT75 Heatdump Temp.                                  |                                                                                                                                                                    |
| 40159           | Number    | -32767      | 32767      | Setting | EP47-BT2 Supply temp S8                                  |                                                                                                                                                                    |
| 40160           | Number    | -32767      | 32767      | Setting | EP46-BT2 Supply temp S7                                  |                                                                                                                                                                    |
| 40161           | Number    | -32767      | 32767      | Setting | EP45-BT2 Supply temp S6                                  |                                                                                                                                                                    |
| 40162           | Number    | -32767      | 32767      | Setting | EP44-BT2 Supply temp S5                                  |                                                                                                                                                                    |
| 40163           | Number    | -32767      | 32767      | Setting | EP47-BT3 Return temp S8                                  |                                                                                                                                                                    |
| 40164           | Number    | -32767      | 32767      | Setting | EP46-BT3 Return temp S7                                  |                                                                                                                                                                    |
| 40165           | Number    | -32767      | 32767      | Setting | EP45-BT3 Return temp S6                                  |                                                                                                                                                                    |
| 40166           | Number    | -32767      | 32767      | Setting | EP44-BT3 Return temp S5                                  |                                                                                                                                                                    |
| 40167           | Number    | -32767      | 32767      | Setting | EP47-BT50 Room Temp S8                                   |                                                                                                                                                                    |
| 40168           | Number    | -32767      | 32767      | Setting | EP46-BT50 Room Temp S7                                   |                                                                                                                                                                    |
| 40169           | Number    | -32767      | 32767      | Setting | EP45-BT50 Room Temp S6                                   |                                                                                                                                                                    |
| 40170           | Number    | -32767      | 32767      | Setting | EP44-BT50 Room Temp S5                                   |                                                                                                                                                                    |
| 40183           | Number    | -32767      | 32767      | Setting | AZ30-BT23 Outdoor temp. ERS 1                            |                                                                                                                                                                    |
| 40185           | Number    | -32767      | 32767      | Setting | BT1 Average, 1h                                          |                                                                                                                                                                    |
| 40188           | Number    | -32767      | 32767      | Setting | EP47-BT50 Room Temp S8 Average                           |                                                                                                                                                                    |
| 40189           | Number    | -32767      | 32767      | Setting | EP46-BT50 Room Temp S7 Average                           |                                                                                                                                                                    |
| 40190           | Number    | -32767      | 32767      | Setting | EP45-BT50 Room Temp S6 Average                           |                                                                                                                                                                    |
| 40191           | Number    | -32767      | 32767      | Setting | EP44-BT50 Room Temp S5 Average                           |                                                                                                                                                                    |
| 40192           | Number    | -32767      | 32767      | Setting | EP23-BT50 Room Temp S4 Average                           |                                                                                                                                                                    |
| 40193           | Number    | -32767      | 32767      | Setting | EP22-BT50 Room Temp S3 Average                           |                                                                                                                                                                    |
| 40194           | Number    | -32767      | 32767      | Setting | EP21-BT50 Room Temp S2 Average                           |                                                                                                                                                                    |
| 40195           | Number    | -32767      | 32767      | Setting | BT50 Room Temp S1 Average                                |                                                                                                                                                                    |
| 40212           | Number    | -32767      | 32767      | Setting | BT74 Average                                             |                                                                                                                                                                    |
| 40216           | Number    | -32767      | 32767      | Setting | BT25 Ext. supply temp, cooling                           |                                                                                                                                                                    |
| 40217           | Number    | -32767      | 32767      | Setting | Calc. Supply S8                                          |                                                                                                                                                                    |
| 40218           | Number    | -32767      | 32767      | Setting | Calc. Supply S7                                          |                                                                                                                                                                    |
| 40219           | Number    | -32767      | 32767      | Setting | Calc. Supply S6                                          |                                                                                                                                                                    |
| 40220           | Number    | -32767      | 32767      | Setting | Calculated Supply S5                                     |                                                                                                                                                                    |
| 40221           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S8                                  |                                                                                                                                                                    |
| 40222           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S7                                  |                                                                                                                                                                    |
| 40223           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S6                                  |                                                                                                                                                                    |
| 40224           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S5                                  |                                                                                                                                                                    |
| 40305           | Number    | 0           | 255        | Setting | Mixing Valve State S8                                    |                                                                                                                                                                    |
| 40306           | Number    | 0           | 255        | Setting | Mixing Valve State S7                                    |                                                                                                                                                                    |
| 40307           | Number    | 0           | 255        | Setting | Mixing Valve State S6                                    |                                                                                                                                                                    |
| 40308           | Number    | 0           | 255        | Setting | Mixing Valve State S5                                    |                                                                                                                                                                    |
| 40310           | Number    | 0           | 255        | Setting | External ERS 1 accessory relays                          |                                                                                                                                                                    |
| 40311           | Number    | 0           | 255        | Setting | External ERS 1 accessory GQ2 speed                       |                                                                                                                                                                    |
| 40312           | Number    | 0           | 255        | Setting | External ERS 1 accessory GQ3 speed                       |                                                                                                                                                                    |
| 40316           | Number    | 0           | 255        | Setting | Inverter limit status                                    |                                                                                                                                                                    |
| 40317           | Number    | 0           | 65535      | Setting | Inverter drive status                                    |                                                                                                                                                                    |
| 40321           | Number    | 0           | 65535      | Setting | Compressor Frequency, Request                            |                                                                                                                                                                    |
| 40322           | Number    | 0           | 65535      | Setting | Max Compressor Frequency, Heating                        |                                                                                                                                                                    |
| 40323           | Number    | 0           | 65535      | Setting | Inverter alarm code                                      |                                                                                                                                                                    |
| 40324           | Number    | 0           | 65535      | Setting | Inverter fault code                                      |                                                                                                                                                                    |
| 40326           | Number    | 0           | 65535      | Setting | Inverter drive command                                   |                                                                                                                                                                    |
| 40327           | Number    | 0           | 65535      | Setting | NIBE Inverter Pic version                                |                                                                                                                                                                    |
| 40328           | Number    | 0           | 65535      | Setting | NIBE Inverter 8051 version                               |                                                                                                                                                                    |
| 40329           | Number    | 0           | 65535      | Setting | NIBE Inverter Def. Wizard                                |                                                                                                                                                                    |
| 40330           | Number    | 0           | 65535      | Setting | NIBE Inverter Mce version                                |                                                                                                                                                                    |
| 40331           | Number    | 0           | 65535      | Setting | NIBE Inverter Hw version                                 |                                                                                                                                                                    |
| 40332           | Number    | 0           | 65535      | Setting | NIBE Inverter Hw type                                    |                                                                                                                                                                    |
| 40339           | Number    | 0           | 255        | Setting | External adjustment activated via input S8               |                                                                                                                                                                    |
| 40340           | Number    | 0           | 255        | Setting | External adjustment activated via input S7               |                                                                                                                                                                    |
| 40341           | Number    | 0           | 255        | Setting | External adjustment activated via input S6               |                                                                                                                                                                    |
| 40342           | Number    | 0           | 255        | Setting | External adjustment activated via input S5               |                                                                                                                                                                    |
| 40365           | Number    | 0           | 255        | Setting | Extra heating system pump S8                             |                                                                                                                                                                    |
| 40366           | Number    | 0           | 255        | Setting | Extra heating system pump S7                             |                                                                                                                                                                    |
| 40367           | Number    | 0           | 255        | Setting | Extra heating system pump S6                             |                                                                                                                                                                    |
| 40368           | Number    | 0           | 255        | Setting | Extra heating system pump S5                             |                                                                                                                                                                    |
| 40369           | Number    | 0           | 255        | Setting | Extra cooling HPAC, ACS                                  |                                                                                                                                                                    |
| 40625           | Number    | -32767      | 32767      | Setting | BT82 HW Comfort Return Temp                              |                                                                                                                                                                    |
| 40626           | Number    | -32767      | 32767      | Setting | BT83 HW Comfort Cylinder Temp                            |                                                                                                                                                                    |
| 40755           | Number    | 0           | 9999999    | Setting | Tot. ext. HW add op.time                                 |                                                                                                                                                                    |
| 40771           | Number    | 0           | 4294967295 | Setting | Heat Meter - Pool2 Cpr EP14                              |                                                                                                                                                                    |
| 40792           | Number    | 0           | 255        | Setting | OPT state                                                |                                                                                                                                                                    |
| 40793           | Number    | 0           | 65535      | Setting | OPT version                                              |                                                                                                                                                                    |
| 40801           | Number    | -32767      | 32767      | Setting | OPT rel. modulation level                                |                                                                                                                                                                    |
| 40802           | Number    | -32767      | 32767      | Setting | OPT boiler temperature                                   |                                                                                                                                                                    |
| 40806           | Number    | 0           | 65535      | Setting | OPT boiler op. time                                      |                                                                                                                                                                    |
| 40813           | Number    | 0           | 255        | Setting | Compressor slow down reason                              |                                                                                                                                                                    |
| 40834           | Number    | -32767      | 32767      | Setting | BM1 Humidity                                             |                                                                                                                                                                    |
| 40856           | Number    | -32767      | 32767      | Setting | BM1 BT50 Room temp.                                      |                                                                                                                                                                    |
| 40857           | Number    | -32767      | 32767      | Setting | BM1 Pressure                                             |                                                                                                                                                                    |
| 40858           | Number    | -32767      | 32767      | Setting | BM1 Dewpoint                                             |                                                                                                                                                                    |
| 40868           | Number    | 0           | 255        | Setting | +Adjust AUX Port                                         |                                                                                                                                                                    |
| 40870           | Number    | 0           | 255        | Setting | +Adjust OP mode                                          |                                                                                                                                                                    |
| 40871           | Number    | 0           | 255        | Setting | +Adjust Comfort mode                                     |                                                                                                                                                                    |
| 40872           | Number    | -128        | 127        | Setting | +Adjust Parallell adjustment                             |                                                                                                                                                                    |
| 40873           | Number    | -32767      | 32767      | Setting | +Adjust Humidity                                         |                                                                                                                                                                    |
| 40874           | Number    | -32767      | 32767      | Setting | +Adjust Temp indoor                                      |                                                                                                                                                                    |
| 40875           | Number    | -32767      | 32767      | Setting | +Adjust Temp outdoor                                     |                                                                                                                                                                    |
| 40876           | Number    | 0           | 65535      | Setting | +Adjust Version                                          |                                                                                                                                                                    |
| 40877           | Number    | 0           | 255        | Setting | +Adjust Activated                                        |                                                                                                                                                                    |
| 40878           | Number    | 0           | 255        | Setting | +Adjust Need                                             |                                                                                                                                                                    |
| 40889           | Number    | -32767      | 32767      | Setting | BT64 Average                                             |                                                                                                                                                                    |
| 40912           | String    | 0           | 255        | Setting | EQ1 State ACS Thermostat                                 | 10=off, 40=active wait, 50=active                                                                                                                                  |
| 40913           | String    | 0           | 255        | Setting | EQ1 State ACS Thermostat Heat Dump                       | 10=shunt off, 20=shunt open, 30=shunt closed                                                                                                                       |
| 40940           | Number    | -30000      | 30000      | Setting | Degree Minutes (32 bit)                                  |                                                                                                                                                                    |
| 40942           | Number    | 0           | 255        | Setting | External ERS 1 accessory block status                    |                                                                                                                                                                    |
| 40943           | String    | 0           | 255        | Setting | External ERS 1 accessory EB17                            | 0=open.                                                                                                                                                            |
| 40993           | Number    | 0           | 65535      | Setting | Inverter min speed                                       |                                                                                                                                                                    |
| 40994           | Number    | 0           | 65535      | Setting | Inverter max speed                                       |                                                                                                                                                                    |
| 40995           | Number    | 0           | 2147483647 | Setting | External Energy Meter 2 Accumulated Energy               |                                                                                                                                                                    |
| 40997           | Number    | 0           | 2147483647 | Setting | External Energy Meter 1 Accumulated Energy               |                                                                                                                                                                    |
| 41027           | Number    | -32767      | 32767      | Setting | Humidity average                                         |                                                                                                                                                                    |
| 41186           | Number    | -32767      | 32767      | Setting | Set point OPT boiler                                     |                                                                                                                                                                    |
| 41189           | Number    | -32767      | 32767      | Setting | AA20-BE5 EME10 Current                                   |                                                                                                                                                                    |
| 41190           | Number    | -32767      | 32767      | Setting | AA20-BE5 EME10 Average Current                           |                                                                                                                                                                    |
| 41191           | Number    | 0           | 255        | Setting | PV Panel State                                           |                                                                                                                                                                    |
| 41210           | Number    | -32767      | 32767      | Setting | AZ4-BT50 Room temp                                       |                                                                                                                                                                    |
| 41211           | Number    | -32767      | 32767      | Setting | AZ3-BT50 Room temp                                       |                                                                                                                                                                    |
| 41212           | Number    | -32767      | 32767      | Setting | AZ2-BT50 Room temp                                       |                                                                                                                                                                    |
| 41213           | Number    | -32767      | 32767      | Setting | AZ1-BT50 Room temp                                       |                                                                                                                                                                    |
| 41256           | Number    | 0           | 255        | Setting | Fan speed current                                        |                                                                                                                                                                    |
| 41257           | Number    | 0           | 255        | Setting | Fan speed current                                        |                                                                                                                                                                    |
| 41258           | Number    | 0           | 255        | Setting | Fan speed current                                        |                                                                                                                                                                    |
| 41265           | String    | 0           | 255        | Setting | Smart Home Mode                                          | 0=Default, 1=Away from home, 2=Vacation                                                                                                                            |
| 41266           | Number    | -128        | 127        | Setting | Offset to smart home system                              |                                                                                                                                                                    |
| 41267           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 8                                   |                                                                                                                                                                    |
| 41268           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 7                                   |                                                                                                                                                                    |
| 41269           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 6                                   |                                                                                                                                                                    |
| 41270           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 5                                   |                                                                                                                                                                    |
| 41271           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 4                                   |                                                                                                                                                                    |
| 41272           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 3                                   |                                                                                                                                                                    |
| 41273           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 2                                   |                                                                                                                                                                    |
| 41274           | Number    | 0           | 255        | Setting | Smart Home ctrl syst 1                                   |                                                                                                                                                                    |
| 41287           | Number    | 0           | 255        | Setting | OPT boiler has priority hot water                        |                                                                                                                                                                    |
| 41393           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, energy source prio 7, start DM      |                                                                                                                                                                    |
| 41395           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, energy source prio 6, start DM      |                                                                                                                                                                    |
| 41397           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, energy source prio 5, start DM      |                                                                                                                                                                    |
| 41399           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, energy source prio 4, start DM      |                                                                                                                                                                    |
| 41401           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, energy source prio 3, start DM      |                                                                                                                                                                    |
| 41403           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, energy source prio 2, start DM      |                                                                                                                                                                    |
| 41405           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, energy source prio 1, start DM      |                                                                                                                                                                    |
| 41421           | Number    | -2147483648 | 2147483647 | Setting | Smart energy source, degree minute min value             |                                                                                                                                                                    |
| 41424           | Number    | 0           | 65535      | Setting | Smart energy source, actual OPT10 addition price         |                                                                                                                                                                    |
| 41425           | Number    | 0           | 65535      | Setting | Smart energy source, actual shunt add price              |                                                                                                                                                                    |
| 41426           | Number    | 0           | 65535      | Setting | Smart energy source, actual ext. step add price          |                                                                                                                                                                    |
| 41427           | Number    | 0           | 65535      | Setting | Smart energy source, actual electricity price            |                                                                                                                                                                    |
| 41429           | Number    | -32767      | 32767      | Setting | EP12-BT57 Collector In                                   |                                                                                                                                                                    |
| 41430           | Number    | -32767      | 32767      | Setting | EP12-BT58 Collector Out                                  |                                                                                                                                                                    |
| 41928           | Number    | 0           | 65535      | Setting | Smart Price Adaption Price                               |                                                                                                                                                                    |
| 41929           | Number    | 0           | 255        | Setting | Smart Price Adaption Price Level                         |                                                                                                                                                                    |
| 41930           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 10                                        |                                                                                                                                                                    |
| 41931           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 9                                         |                                                                                                                                                                    |
| 41932           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 8                                         |                                                                                                                                                                    |
| 41933           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 7                                         |                                                                                                                                                                    |
| 41934           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 6                                         |                                                                                                                                                                    |
| 41935           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 5                                         |                                                                                                                                                                    |
| 41936           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 4                                         |                                                                                                                                                                    |
| 41937           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 3                                         |                                                                                                                                                                    |
| 41938           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 2                                         |                                                                                                                                                                    |
| 41939           | Number    | 0           | 65535      | Setting | AA23-BE5 Power 1                                         |                                                                                                                                                                    |
| 41940           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 10                                   |                                                                                                                                                                    |
| 41941           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 9                                    |                                                                                                                                                                    |
| 41942           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 8                                    |                                                                                                                                                                    |
| 41943           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 7                                    |                                                                                                                                                                    |
| 41944           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 6                                    |                                                                                                                                                                    |
| 41945           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 5                                    |                                                                                                                                                                    |
| 41946           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 4                                    |                                                                                                                                                                    |
| 41947           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 3                                    |                                                                                                                                                                    |
| 41948           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 2                                    |                                                                                                                                                                    |
| 41949           | Number    | 0           | 65535      | Setting | AA23-BE5 Error High 1                                    |                                                                                                                                                                    |
| 41950           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 10                                    |                                                                                                                                                                    |
| 41951           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 9                                     |                                                                                                                                                                    |
| 41952           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 8                                     |                                                                                                                                                                    |
| 41953           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 7                                     |                                                                                                                                                                    |
| 41954           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 6                                     |                                                                                                                                                                    |
| 41955           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 5                                     |                                                                                                                                                                    |
| 41956           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 4                                     |                                                                                                                                                                    |
| 41957           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 3                                     |                                                                                                                                                                    |
| 41958           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 2                                     |                                                                                                                                                                    |
| 41959           | Number    | 0           | 65535      | Setting | AA23-BE5 Error Low 1                                     |                                                                                                                                                                    |
| 41960           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 10                               |                                                                                                                                                                    |
| 41961           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 9                                |                                                                                                                                                                    |
| 41962           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 8                                |                                                                                                                                                                    |
| 41963           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 7                                |                                                                                                                                                                    |
| 41964           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 6                                |                                                                                                                                                                    |
| 41965           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 5                                |                                                                                                                                                                    |
| 41966           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 4                                |                                                                                                                                                                    |
| 41967           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 3                                |                                                                                                                                                                    |
| 41968           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 2                                |                                                                                                                                                                    |
| 41969           | Number    | 0           | 255        | Setting | AA23-BE5 Com Percentage 1                                |                                                                                                                                                                    |
| 41980           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 10                                     |                                                                                                                                                                    |
| 41981           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 9                                      |                                                                                                                                                                    |
| 41982           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 8                                      |                                                                                                                                                                    |
| 41983           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 7                                      |                                                                                                                                                                    |
| 41984           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 6                                      |                                                                                                                                                                    |
| 41985           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 5                                      |                                                                                                                                                                    |
| 41986           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 4                                      |                                                                                                                                                                    |
| 41987           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 3                                      |                                                                                                                                                                    |
| 41988           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 2                                      |                                                                                                                                                                    |
| 41989           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage1 1                                      |                                                                                                                                                                    |
| 41990           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 10                                     |                                                                                                                                                                    |
| 41991           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 9                                      |                                                                                                                                                                    |
| 41992           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 8                                      |                                                                                                                                                                    |
| 41993           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 7                                      |                                                                                                                                                                    |
| 41994           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 6                                      |                                                                                                                                                                    |
| 41995           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 5                                      |                                                                                                                                                                    |
| 41996           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 4                                      |                                                                                                                                                                    |
| 41997           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 3                                      |                                                                                                                                                                    |
| 41998           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 2                                      |                                                                                                                                                                    |
| 41999           | Number    | 0           | 65535      | Setting | AA23-BE5 Voltage2 1                                      |                                                                                                                                                                    |
| 42000           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 10                                  |                                                                                                                                                                    |
| 42001           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 9                                   |                                                                                                                                                                    |
| 42002           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 8                                   |                                                                                                                                                                    |
| 42003           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 7                                   |                                                                                                                                                                    |
| 42004           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 6                                   |                                                                                                                                                                    |
| 42005           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 5                                   |                                                                                                                                                                    |
| 42006           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 4                                   |                                                                                                                                                                    |
| 42007           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 3                                   |                                                                                                                                                                    |
| 42008           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 2                                   |                                                                                                                                                                    |
| 42009           | Number    | 0           | 65535      | Setting | AA23-BE5 Temperature 1                                   |                                                                                                                                                                    |
| 42010           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 10                                       |                                                                                                                                                                    |
| 42012           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 9                                        |                                                                                                                                                                    |
| 42014           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 8                                        |                                                                                                                                                                    |
| 42016           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 7                                        |                                                                                                                                                                    |
| 42018           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 6                                        |                                                                                                                                                                    |
| 42020           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 5                                        |                                                                                                                                                                    |
| 42022           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 4                                        |                                                                                                                                                                    |
| 42024           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 3                                        |                                                                                                                                                                    |
| 42026           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 2                                        |                                                                                                                                                                    |
| 42028           | Number    | 0           | 4294967295 | Setting | AA23-BE5 Energy 1                                        |                                                                                                                                                                    |
| 42030           | Number    | 0           | 65535      | Setting | AA23-BE5 EME20 Version                                   |                                                                                                                                                                    |
| 42033           | Number    | 0           | 255        | Setting | PV Panel Heat Offset                                     |                                                                                                                                                                    |
| 42034           | Number    | 0           | 255        | Setting | PV Panel Pool Offset                                     |                                                                                                                                                                    |
| 42035           | Number    | 0           | 4294967295 | Setting | AA23-BE5 EME20 Total Power                               |                                                                                                                                                                    |
| 42037           | Number    | 0           | 4294967295 | Setting | AA23-BE5 EME20 Total Average Power                       |                                                                                                                                                                    |
| 42075           | Number    | 0           | 4294967295 | Setting | AA23-BE5 EME20 Total Energy                              |                                                                                                                                                                    |
| 42080           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 504                                       |                                                                                                                                                                    |
| 42081           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 505                                       |                                                                                                                                                                    |
| 42082           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 506                                       |                                                                                                                                                                    |
| 42083           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 507                                       |                                                                                                                                                                    |
| 42084           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 508                                       |                                                                                                                                                                    |
| 42085           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 509                                       |                                                                                                                                                                    |
| 42086           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 510                                       |                                                                                                                                                                    |
| 42087           | Number    | 0           | 255        | Setting | AA23-BE5 Alarm 511                                       |                                                                                                                                                                    |
| 42100           | Number    | -32767      | 32767      | Setting | BT1 Average, 24h                                         |                                                                                                                                                                    |
| 42101           | Number    | -32767      | 32767      | Setting | Used heating power average, 24h                          |                                                                                                                                                                    |
| 42136           | Number    | -32767      | 32767      | Setting | BT22 Supply air temp.                                    |                                                                                                                                                                    |
| 42137           | Number    | -32767      | 32767      | Setting | BT22 Supply air temp.                                    |                                                                                                                                                                    |
| 42138           | Number    | -32767      | 32767      | Setting | BT22 Supply air temp.                                    |                                                                                                                                                                    |
| 42139           | Number    | -32767      | 32767      | Setting | AZ30-BT23 Outdoor temp. ERS 4                            |                                                                                                                                                                    |
| 42140           | Number    | -32767      | 32767      | Setting | AZ30-BT23 Outdoor temp. ERS 3                            |                                                                                                                                                                    |
| 42141           | Number    | -32767      | 32767      | Setting | AZ30-BT23 Outdoor temp. ERS 2                            |                                                                                                                                                                    |
| 42150           | Number    | 0           | 255        | Setting | External ERS 4 accessory relays                          |                                                                                                                                                                    |
| 42151           | Number    | 0           | 255        | Setting | External ERS 3 accessory relays                          |                                                                                                                                                                    |
| 42152           | Number    | 0           | 255        | Setting | External ERS 2 accessory relays                          |                                                                                                                                                                    |
| 42153           | Number    | 0           | 255        | Setting | External ERS 4 accessory GQ2 speed                       |                                                                                                                                                                    |
| 42154           | Number    | 0           | 255        | Setting | External ERS 3 accessory GQ2 speed                       |                                                                                                                                                                    |
| 42155           | Number    | 0           | 255        | Setting | External ERS 2 accessory GQ2 speed                       |                                                                                                                                                                    |
| 42156           | Number    | 0           | 255        | Setting | External ERS 4 accessory GQ3 speed                       |                                                                                                                                                                    |
| 42157           | Number    | 0           | 255        | Setting | External ERS 3 accessory GQ3 speed                       |                                                                                                                                                                    |
| 42158           | Number    | 0           | 255        | Setting | External ERS 2 accessory GQ3 speed                       |                                                                                                                                                                    |
| 42159           | Number    | 0           | 255        | Setting | External ERS 4 accessory block status                    |                                                                                                                                                                    |
| 42160           | Number    | 0           | 255        | Setting | External ERS 3 accessory block status                    |                                                                                                                                                                    |
| 42161           | Number    | 0           | 255        | Setting | External ERS 2 accessory block status                    |                                                                                                                                                                    |
| 42162           | String    | 0           | 255        | Setting | External ERS 4 accessory EB17                            | 0=open.                                                                                                                                                            |
| 42163           | String    | 0           | 255        | Setting | External ERS 3 accessory EB17                            | 0=open.                                                                                                                                                            |
| 42164           | String    | 0           | 255        | Setting | External ERS 2 accessory EB17                            | 0=open.                                                                                                                                                            |
| 42437           | Number    | 0           | 4294967295 | Setting | Heat Meter - HW Cpr and Add - Total system               |                                                                                                                                                                    |
| 42439           | Number    | 0           | 4294967295 | Setting | Heat Meter - Heat Cpr and Add - Total system             |                                                                                                                                                                    |
| 42441           | Number    | 0           | 4294967295 | Setting | Heat Meter - Cooling Cpr - Total system                  |                                                                                                                                                                    |
| 42443           | Number    | 0           | 4294967295 | Setting | Heat Meter - Pool Cpr - Total system                     |                                                                                                                                                                    |
| 42445           | Number    | 0           | 4294967295 | Setting | Heat Meter - HW Cpr - Total system                       |                                                                                                                                                                    |
| 42447           | Number    | 0           | 4294967295 | Setting | Heat Meter - Heat Cpr - Total system                     |                                                                                                                                                                    |
| 42464           | Number    | 0           | 255        | Setting | External ERS 4 fire place guard                          |                                                                                                                                                                    |
| 42465           | Number    | 0           | 255        | Setting | External ERS 3 fire place guard                          |                                                                                                                                                                    |
| 42466           | Number    | 0           | 255        | Setting | External ERS 2 fire place guard                          |                                                                                                                                                                    |
| 42467           | Number    | 0           | 255        | Setting | External ERS 1 fire place guard                          |                                                                                                                                                                    |
| 42504           | Number    | 0           | 4294967295 | Setting | External Energy Meter Accumulated System                 |                                                                                                                                                                    |
| 43001           | Number    | 0           | 65535      | Setting | Software version                                         |                                                                                                                                                                    |
| 43005           | Number    | -30000      | 30000      | Setting | Degree Minutes (16 bit)                                  |                                                                                                                                                                    |
| 43006           | Number    | -32767      | 32767      | Setting | Calc. Supply S4                                          |                                                                                                                                                                    |
| 43007           | Number    | -32767      | 32767      | Setting | Calc. Supply S3                                          |                                                                                                                                                                    |
| 43008           | Number    | -32767      | 32767      | Setting | Calc. Supply S2                                          |                                                                                                                                                                    |
| 43009           | Number    | -32767      | 32767      | Setting | Calc. Supply S1                                          |                                                                                                                                                                    |
| 43013           | String    | 0           | 255        | Setting | Freeze Protection Status                                 | 1=Freeze protection active                                                                                                                                         |
| 43024           | String    | 0           | 255        | Setting | Status Cooling                                           | 0=Off, 1=On                                                                                                                                                        |
| 43064           | Number    | -32767      | 32767      | Setting | Heat Medium Flow dT Set Point                            |                                                                                                                                                                    |
| 43065           | Number    | -32767      | 32767      | Setting | Heat Medium Flow dT Actual                               |                                                                                                                                                                    |
| 43081           | Number    | 0           | 1000000    | Setting | Tot. op.time add.                                        |                                                                                                                                                                    |
| 43084           | Number    | -32767      | 32767      | Setting | Int. el.add. Power                                       |                                                                                                                                                                    |
| 43086           | String    | 0           | 255        | Setting | Prio                                                     | 10=Off, 20=Hot Water, 30=Heat, 40=Pool, 41=Pool 2, 50=Transfer, 60=Cooling                                                                                         |
| 43091           | Number    | 0           | 255        | Setting | Int. el.add. State                                       |                                                                                                                                                                    |
| 43093           | Number    | 0           | 255        | Setting | Mixing Valve State S4                                    |                                                                                                                                                                    |
| 43094           | Number    | 0           | 255        | Setting | Mixing Valve State S3                                    |                                                                                                                                                                    |
| 43095           | Number    | 0           | 255        | Setting | Mixing Valve State S2                                    |                                                                                                                                                                    |
| 43096           | Number    | 0           | 255        | Setting | Mixing Valve State S1                                    |                                                                                                                                                                    |
| 43097           | String    | 0           | 255        | Setting | Status of the shunt controlled additional heat accessory | 10=Off, 20=Running, 30=Passive                                                                                                                                     |
| 43103           | Number    | 0           | 255        | Setting | HPAC state                                               |                                                                                                                                                                    |
| 43108           | Number    | 0           | 255        | Setting | Fan speed current                                        |                                                                                                                                                                    |
| 43122           | Number    | -32767      | 32767      | Setting | Compr. current min.freq.                                 |                                                                                                                                                                    |
| 43123           | Number    | -32767      | 32767      | Setting | Compr. current max.freq.                                 |                                                                                                                                                                    |
| 43132           | Number    | 0           | 65535      | Setting | Inverter com. timer                                      |                                                                                                                                                                    |
| 43136           | Number    | 0           | 65535      | Setting | Compressor Frequency, Actual                             |                                                                                                                                                                    |
| 43140           | Number    | -32767      | 32767      | Setting | Inverter Temperature                                     |                                                                                                                                                                    |
| 43141           | Number    | 0           | 65535      | Setting | compr. in power                                          |                                                                                                                                                                    |
| 43147           | Number    | -32767      | 32767      | Setting | Compr. in current                                        |                                                                                                                                                                    |
| 43152           | Number    | 0           | 255        | Setting | Internal cooling blocked                                 |                                                                                                                                                                    |
| 43158           | Number    | 0           | 255        | Setting | External adjustment activated via input S4               |                                                                                                                                                                    |
| 43159           | Number    | 0           | 255        | Setting | External adjustment activated via input S3               |                                                                                                                                                                    |
| 43160           | Number    | 0           | 255        | Setting | External adjustment activated via input S2               |                                                                                                                                                                    |
| 43161           | Number    | 0           | 255        | Setting | External adjustment activated via input S1               |                                                                                                                                                                    |
| 43163           | String    | 0           | 255        | Setting | Blocking status of the shunt controlled add heat acc     | 0=Unblocked, 1=Blocked                                                                                                                                             |
| 43164           | Number    | 0           | 255        | Setting | Cooling blocked                                          |                                                                                                                                                                    |
| 43171           | String    | 0           | 255        | Setting | Blocking status of the step controlled add heat acc      | 0=Unblocked, 1=Blocked                                                                                                                                             |
| 43180           | String    | 0           | 255        | Setting | HWC Pump Status GP11                                     | 1=on, 0=off                                                                                                                                                        |
| 43182           | Number    | 0           | 65535      | Setting | Compressor Frequency, Target                             |                                                                                                                                                                    |
| 43239           | Number    | 0           | 9999999    | Setting | Tot. HW op.time add.                                     |                                                                                                                                                                    |
| 43375           | Number    | -32767      | 32767      | Setting | compr. in power mean                                     |                                                                                                                                                                    |
| 43395           | Number    | 0           | 255        | Setting | HPAC Relays                                              |                                                                                                                                                                    |
| 43416           | Number    | 0           | 9999999    | Setting | Compressor starts EB100-EP14                             |                                                                                                                                                                    |
| 43420           | Number    | 0           | 9999999    | Setting | Tot. op.time compr. EB100-EP14                           |                                                                                                                                                                    |
| 43424           | Number    | 0           | 9999999    | Setting | Tot. HW op.time compr. EB100-EP14                        |                                                                                                                                                                    |
| 43427           | String    | 0           | 255        | Setting | Compressor State EP14                                    | 20=Stopped, 40=Starting, 60=Running, 100=Stopping                                                                                                                  |
| 43431           | String    | 0           | 255        | Setting | Supply Pump State EP14                                   | 10=off, 15=starting, 20=on, 40=10-day mode, 80=calibration                                                                                                         |
| 43433           | String    | 0           | 255        | Setting | Brine Pump State EP14                                    | 10=off, 15=starting, 20=on, 40=10-day mode, 80=calibration                                                                                                         |
| 43435           | String    | 0           | 255        | Setting | Cpr Status EP14                                          | 1=on, 0=off, 0=Off, 1=On                                                                                                                                           |
| 43437           | Number    | 0           | 255        | Setting | Supply Pump Speed EP14                                   |                                                                                                                                                                    |
| 43439           | Number    | 0           | 255        | Setting | EP14-GP2 Brine Pump Status EP14                          |                                                                                                                                                                    |
| 43484           | String    | 0           | 255        | Setting | FLM 4 Cooling Status                                     | 1=yes, 0=no                                                                                                                                                        |
| 43485           | String    | 0           | 255        | Setting | FLM 3 Cooling Status                                     | 1=yes, 0=no                                                                                                                                                        |
| 43486           | String    | 0           | 255        | Setting | FLM 2 Cooling Status                                     | 1=yes, 0=no                                                                                                                                                        |
| 43487           | String    | 0           | 255        | Setting | FLM 1 Cooling Status                                     | 1=yes, 0=no                                                                                                                                                        |
| 43514           | String    | 0           | 255        | Setting | EB100-EP14 PCA Base Relays                               | 1=on, 0=off. Bit0 K4 Bit1 K3 Bit2 K2 Bit3 K1                                                                                                                       |
| 43516           | Number    | 0           | 255        | Setting | PCA-Power Relays EP14                                    |                                                                                                                                                                    |
| 43542           | Number    | -32767      | 32767      | Setting | Calculated supply air temp.                              |                                                                                                                                                                    |
| 43555           | String    | 0           | 255        | Setting | HW Comfort Shunt State                                   | 10=shunt off, 20=shunt open, 30=shunt closed                                                                                                                       |
| 43556           | String    | 0           | 255        | Setting | HW Comfort Add Status                                    | 1=on, 0=off                                                                                                                                                        |
| 43560           | Number    | 0           | 255        | Setting | Pool 2 blocked                                           |                                                                                                                                                                    |
| 43561           | Number    | 0           | 255        | Setting | Pool 1 blocked                                           |                                                                                                                                                                    |
| 43563           | Number    | 0           | 255        | Setting | GP9 Pool 2 Valve                                         |                                                                                                                                                                    |
| 43564           | Number    | 0           | 255        | Setting | GP9 Pool 1 Valve                                         |                                                                                                                                                                    |
| 44266           | Number    | -30000      | 30000      | Setting | Cool Degree Minutes                                      |                                                                                                                                                                    |
| 44267           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S4                                  |                                                                                                                                                                    |
| 44268           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S3                                  |                                                                                                                                                                    |
| 44269           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S2                                  |                                                                                                                                                                    |
| 44270           | Number    | -32767      | 32767      | Setting | Calc. Cooling Supply S1                                  |                                                                                                                                                                    |
| 44276           | Number    | 0           | 255        | Setting | State ACS                                                |                                                                                                                                                                    |
| 44277           | String    | 0           | 255        | Setting | EQ1-QN25 State ACS Heat Dump                             | 10=shunt off, 20=shunt open, 30=shunt closed                                                                                                                       |
| 44278           | String    | 0           | 255        | Setting | EQ1-QN18 State ACS Cool Dump                             | 10=shunt off, 20=shunt open, 30=shunt closed                                                                                                                       |
| 44298           | Number    | 0           | 4294967295 | Setting | Heat Meter - HW Cpr and Add EP14                         |                                                                                                                                                                    |
| 44300           | Number    | 0           | 4294967295 | Setting | Heat Meter - Heat Cpr and Add EP14                       |                                                                                                                                                                    |
| 44302           | Number    | 0           | 4294967295 | Setting | Heat Meter - Cooling Cpr EP14                            |                                                                                                                                                                    |
| 44304           | Number    | 0           | 4294967295 | Setting | Heat Meter - Pool Cpr EP14                               |                                                                                                                                                                    |
| 44306           | Number    | 0           | 4294967295 | Setting | Heat Meter - HW Cpr EP14                                 |                                                                                                                                                                    |
| 44308           | Number    | 0           | 4294967295 | Setting | Heat Meter - Heat Cpr EP14                               |                                                                                                                                                                    |
| 44331           | Number    | 0           | 255        | Setting | Software release                                         |                                                                                                                                                                    |
| 44744           | Number    | 0           | 255        | Setting | Extra heating system pump S4                             |                                                                                                                                                                    |
| 44745           | Number    | 0           | 255        | Setting | Extra heating system pump S3                             |                                                                                                                                                                    |
| 44746           | Number    | 0           | 255        | Setting | Extra heating system pump S2                             |                                                                                                                                                                    |
| 44748           | String    | 0           | 255        | Setting | Pool 2 Pump Status                                       | 1=on, 0=off                                                                                                                                                        |
| 44749           | String    | 0           | 255        | Setting | Pool 1 Pump Status                                       | 1=on, 0=off                                                                                                                                                        |
| 44751           | String    | 0           | 255        | Setting | EQ1-QN12 ACS Valve                                       | 1=open, 0=closed                                                                                                                                                   |
| 44752           | String    | 0           | 255        | Setting | EQ1-GP20 ACS Dump Signal                                 | 1=running, 0=off                                                                                                                                                   |
| 44753           | Number    | 0           | 255        | Setting | Passive Cool Shunt                                       |                                                                                                                                                                    |
| 44754           | Number    | 0           | 255        | Setting | GP13 Passive Cool Pool                                   |                                                                                                                                                                    |
| 44756           | Number    | 0           | 255        | Setting | State ground water pump                                  |                                                                                                                                                                    |
| 44874           | Number    | 0           | 255        | Setting | State SG Ready                                           |                                                                                                                                                                    |
| 44878           | Number    | 0           | 255        | Setting | SG Ready input A                                         |                                                                                                                                                                    |
| 44879           | Number    | 0           | 255        | Setting | SG Ready input B                                         |                                                                                                                                                                    |
| 44896           | Number    | -128        | 127        | Setting | Smart Price Adaption Heating Offset                      |                                                                                                                                                                    |
| 44897           | String    | -128        | 127        | Setting | Smart Price Adaption HW Comfort Mode                     | 0=Eco, 1=Normal, 2=Luxury, 10=Normal+, 20=Mini                                                                                                                     |
| 44898           | Number    | -128        | 127        | Setting | Smart Price Adaption Pool Offset                         |                                                                                                                                                                    |
| 44899           | Number    | -128        | 127        | Setting | Smart Price Adaption Cool Offset                         |                                                                                                                                                                    |
| 44908           | Number    | 0           | 255        | Setting | State smart price adaption                               |                                                                                                                                                                    |
| 44910           | Number    | -32767      | 32767      | Setting | Brine Pump dT Actual                                     |                                                                                                                                                                    |
| 44911           | Number    | -32767      | 32767      | Setting | Brine Pump dT Set Point                                  |                                                                                                                                                                    |
| 45001           | Number    | -32767      | 32767      | Setting | Alarm                                                    |                                                                                                                                                                    |
| 47291           | Number    | 0           | 10000      | Setting | Floor drying timer                                       |                                                                                                                                                                    |
| 47325           | Number    | 0           | 7          | Setting | Step controlled add. max. step                           |                                                                                                                                                                    |
| 49239           | Switch    | 0           | 1          | Sensor  | EB101 Installed                                          |                                                                                                                                                                    |
| 40879           | Number    | 1           | 10         | Sensor  | +Adjust Parallell factor                                 |                                                                                                                                                                    |
| 40880           | Number    | -128        | 127        | Sensor  | +Adjust Max change                                       |                                                                                                                                                                    |
| 40881           | Switch    | 0           | 1          | Setting | +Adjust Affect system8                                   |                                                                                                                                                                    |
| 40882           | Switch    | 0           | 1          | Setting | +Adjust Affect system7                                   |                                                                                                                                                                    |
| 40883           | Switch    | 0           | 1          | Setting | +Adjust Affect system6                                   |                                                                                                                                                                    |
| 40884           | Switch    | 0           | 1          | Setting | +Adjust Affect system5                                   |                                                                                                                                                                    |
| 40885           | Switch    | 0           | 1          | Setting | +Adjust Affect system4                                   |                                                                                                                                                                    |
| 40886           | Switch    | 0           | 1          | Setting | +Adjust Affect system3                                   |                                                                                                                                                                    |
| 40887           | Switch    | 0           | 1          | Setting | +Adjust Affect system2                                   |                                                                                                                                                                    |
| 40888           | Switch    | 0           | 1          | Setting | +Adjust Affect system1                                   |                                                                                                                                                                    |
| 42097           | Number    | -128        | 127        | Setting | Ground water pump auto speed                             |                                                                                                                                                                    |
| 45171           | Number    | 0           | 255        | Setting | Alarm Reset                                              |                                                                                                                                                                    |
| 47004           | Number    | 0           | 15         | Setting | Heat Curve S4                                            |                                                                                                                                                                    |
| 47005           | Number    | 0           | 15         | Setting | Heat Curve S3                                            |                                                                                                                                                                    |
| 47006           | Number    | 0           | 15         | Setting | Heat Curve S2                                            |                                                                                                                                                                    |
| 47007           | Number    | 0           | 15         | Setting | Heat Curve S1                                            |                                                                                                                                                                    |
| 47008           | Number    | -10         | 10         | Setting | Heat Offset S4                                           |                                                                                                                                                                    |
| 47009           | Number    | -10         | 10         | Setting | Heat Offset S3                                           |                                                                                                                                                                    |
| 47010           | Number    | -10         | 10         | Setting | Heat Offset S2                                           |                                                                                                                                                                    |
| 47011           | Number    | -10         | 10         | Setting | Heat Offset S1                                           |                                                                                                                                                                    |
| 47012           | Number    | 50          | 700        | Setting | Min Supply System 4                                      |                                                                                                                                                                    |
| 47013           | Number    | 50          | 700        | Setting | Min Supply System 3                                      |                                                                                                                                                                    |
| 47014           | Number    | 50          | 700        | Setting | Min Supply System 2                                      |                                                                                                                                                                    |
| 47015           | Number    | 50          | 700        | Setting | Min Supply System 1                                      |                                                                                                                                                                    |
| 47016           | Number    | 50          | 800        | Setting | Max Supply System 4                                      |                                                                                                                                                                    |
| 47017           | Number    | 50          | 800        | Setting | Max Supply System 3                                      |                                                                                                                                                                    |
| 47018           | Number    | 50          | 800        | Setting | Max Supply System 2                                      |                                                                                                                                                                    |
| 47019           | Number    | 50          | 800        | Setting | Max Supply System 1                                      |                                                                                                                                                                    |
| 47020           | Number    | 5           | 80         | Setting | Own Heating Curve P7                                     |                                                                                                                                                                    |
| 47021           | Number    | 5           | 80         | Setting | Own Heating Curve P6                                     |                                                                                                                                                                    |
| 47022           | Number    | 5           | 80         | Setting | Own Heating Curve P5                                     |                                                                                                                                                                    |
| 47023           | Number    | 5           | 80         | Setting | Own Heating Curve P4                                     |                                                                                                                                                                    |
| 47024           | Number    | 5           | 80         | Setting | Own Heating Curve P3                                     |                                                                                                                                                                    |
| 47025           | Number    | 5           | 80         | Setting | Own Heating Curve P2                                     |                                                                                                                                                                    |
| 47026           | Number    | 5           | 80         | Setting | Own Heating Curve P1                                     |                                                                                                                                                                    |
| 47027           | Number    | -40         | 30         | Setting | Point offset outdoor temp.                               |                                                                                                                                                                    |
| 47028           | Number    | -10         | 10         | Setting | Point offset                                             |                                                                                                                                                                    |
| 47029           | Number    | -10         | 10         | Setting | External adjustment S4                                   |                                                                                                                                                                    |
| 47030           | Number    | -10         | 10         | Setting | External adjustment S3                                   |                                                                                                                                                                    |
| 47031           | Number    | -10         | 10         | Setting | External adjustment S2                                   |                                                                                                                                                                    |
| 47032           | Number    | -10         | 10         | Setting | External adjustment S1                                   |                                                                                                                                                                    |
| 47033           | Number    | 50          | 300        | Setting | External adjustment with room sensor S4                  |                                                                                                                                                                    |
| 47034           | Number    | 50          | 300        | Setting | External adjustment with room sensor S3                  |                                                                                                                                                                    |
| 47035           | Number    | 50          | 300        | Setting | External adjustment with room sensor S2                  |                                                                                                                                                                    |
| 47036           | Number    | 50          | 300        | Setting | External adjustment with room sensor S1                  |                                                                                                                                                                    |
| 47041           | String    | 0           | 4          | Setting | Hot water comfort mode                                   | 0=Economy, 1=Normal, 2=Luxury, 4=Smart Control, 0=Economy, 1=Normal, 2=Luxury                                                                                      |
| 47043           | Number    | 50          | 700        | Setting | Start temperature HW Luxury                              |                                                                                                                                                                    |
| 47044           | Number    | 50          | 700        | Setting | Start temperature HW Normal                              |                                                                                                                                                                    |
| 47045           | Number    | 50          | 700        | Setting | Start temperature HW Economy                             |                                                                                                                                                                    |
| 47046           | Number    | 550         | 700        | Setting | Stop temperature Periodic HW                             |                                                                                                                                                                    |
| 47047           | Number    | 50          | 700        | Setting | Stop temperature HW Luxury                               |                                                                                                                                                                    |
| 47048           | Number    | 50          | 700        | Setting | Stop temperature HW Normal                               |                                                                                                                                                                    |
| 47049           | Number    | 50          | 700        | Setting | Stop temperature HW Economy                              |                                                                                                                                                                    |
| 47050           | Switch    | 0           | 1          | Setting | Periodic HW                                              |                                                                                                                                                                    |
| 47051           | Number    | 1           | 90         | Setting | Periodic HW Interval                                     |                                                                                                                                                                    |
| 47054           | Number    | 1           | 60         | Setting | Run time HWC                                             |                                                                                                                                                                    |
| 47055           | Number    | 0           | 60         | Setting | Still time HWC                                           |                                                                                                                                                                    |
| 47099           | Number    | 0           | 255        | Setting | GMz                                                      |                                                                                                                                                                    |
| 47100           | Number    | 0           | 255        | Setting | Max diff VBF-BerVBF                                      |                                                                                                                                                                    |
| 47101           | Number    | 0           | 255        | Setting | Comp freq reg P                                          |                                                                                                                                                                    |
| 47102           | Number    | -128        | 127        | Setting | Comp freq max delta F                                    |                                                                                                                                                                    |
| 47103           | Number    | -32767      | 32767      | Setting | Min comp freq                                            |                                                                                                                                                                    |
| 47104           | Number    | -32767      | 32767      | Setting | Max comp freq                                            |                                                                                                                                                                    |
| 47131           | String    | 0           | 21         | Setting | Language                                                 | 0=English, 1=Svenska, 2=Deutsch, 3=Francais, 4=Espanol, 5=Suomi, 6=Lietuviu, 7=Cesky, 8=Polski, 9=Nederlands, 10=Norsk, 11=Dansk, 12=Eesti, 13=Latviesu, 16=Magyar |
| 47134           | Number    | 0           | 180        | Setting | Period HW                                                |                                                                                                                                                                    |
| 47135           | Number    | 0           | 180        | Setting | Period Heat                                              |                                                                                                                                                                    |
| 47136           | Number    | 0           | 180        | Setting | Period Pool                                              |                                                                                                                                                                    |
| 47137           | String    | 0           | 2          | Setting | Operational mode                                         | 0=Auto, 1=Manual, 2=Add. heat only                                                                                                                                 |
| 47138           | String    | 10          | 40         | Setting | Operational mode heat medium pump                        | 10=Intermittent, 20=Continous, 30=Economy, 40=Auto                                                                                                                 |
| 47139           | String    | 10          | 30         | Setting | Operational mode brine medium pump                       | 10=Intermittent, 20=Continuous, 30=Economy, 40=Auto                                                                                                                |
| 47206           | Number    | -1000       | -30        | Setting | DM start heating                                         |                                                                                                                                                                    |
| 47209           | Number    | -32767      | 32767      | Setting | DM between add. steps                                    |                                                                                                                                                                    |
| 47210           | Number    | -2000       | -30        | Setting | DM start add. with shunt                                 |                                                                                                                                                                    |
| 47212           | Number    | 0           | 4500       | Setting | Max int add. power                                       |                                                                                                                                                                    |
| 47214           | Number    | 1           | 400        | Setting | Fuse                                                     |                                                                                                                                                                    |
| 47261           | Number    | 0           | 100        | Setting | Exhaust Fan speed 4                                      |                                                                                                                                                                    |
| 47262           | Number    | 0           | 100        | Setting | Exhaust Fan speed 3                                      |                                                                                                                                                                    |
| 47263           | Number    | 0           | 100        | Setting | Exhaust Fan speed 2                                      |                                                                                                                                                                    |
| 47264           | Number    | 0           | 100        | Setting | Exhaust Fan speed 1                                      |                                                                                                                                                                    |
| 47265           | Number    | 0           | 100        | Setting | Exhaust Fan speed normal                                 |                                                                                                                                                                    |
| 47271           | Number    | 1           | 99         | Setting | Fan return time 4                                        |                                                                                                                                                                    |
| 47272           | Number    | 1           | 99         | Setting | Fan return time 3                                        |                                                                                                                                                                    |
| 47273           | Number    | 1           | 99         | Setting | Fan return time 2                                        |                                                                                                                                                                    |
| 47274           | Number    | 1           | 99         | Setting | Fan return time 1                                        |                                                                                                                                                                    |
| 47275           | Number    | 1           | 24         | Setting | Filter Reminder period                                   |                                                                                                                                                                    |
| 47276           | Switch    | 0           | 1          | Setting | Floor drying                                             |                                                                                                                                                                    |
| 47277           | Number    | 0           | 30         | Setting | Floor drying period 7                                    |                                                                                                                                                                    |
| 47278           | Number    | 0           | 30         | Setting | Floor drying period 6                                    |                                                                                                                                                                    |
| 47279           | Number    | 0           | 30         | Setting | Floor drying period 5                                    |                                                                                                                                                                    |
| 47280           | Number    | 0           | 30         | Setting | Floor drying period 4                                    |                                                                                                                                                                    |
| 47281           | Number    | 0           | 30         | Setting | Floor drying period 3                                    |                                                                                                                                                                    |
| 47282           | Number    | 0           | 30         | Setting | Floor drying period 2                                    |                                                                                                                                                                    |
| 47283           | Number    | 0           | 30         | Setting | Floor drying period 1                                    |                                                                                                                                                                    |
| 47284           | Number    | 15          | 70         | Setting | Floor drying temp. 7                                     |                                                                                                                                                                    |
| 47285           | Number    | 15          | 70         | Setting | Floor drying temp. 6                                     |                                                                                                                                                                    |
| 47286           | Number    | 15          | 70         | Setting | Floor drying temp. 5                                     |                                                                                                                                                                    |
| 47287           | Number    | 15          | 70         | Setting | Floor drying temp. 4                                     |                                                                                                                                                                    |
| 47288           | Number    | 15          | 70         | Setting | Floor drying temp. 3                                     |                                                                                                                                                                    |
| 47289           | Number    | 15          | 70         | Setting | Floor drying temp. 2                                     |                                                                                                                                                                    |
| 47290           | Number    | 15          | 70         | Setting | Floor drying temp. 1                                     |                                                                                                                                                                    |
| 47300           | Number    | -400        | 200        | Setting | DOT                                                      |                                                                                                                                                                    |
| 47301           | Number    | 10          | 250        | Setting | delta T at DOT                                           |                                                                                                                                                                    |
| 47302           | Switch    | 0           | 1          | Setting | Climate system 2 accessory                               |                                                                                                                                                                    |
| 47303           | Switch    | 0           | 1          | Setting | Climate system 3 accessory                               |                                                                                                                                                                    |
| 47304           | Switch    | 0           | 1          | Setting | Climate system 4 accessory                               |                                                                                                                                                                    |
| 47305           | Number    | 1           | 100        | Setting | Climate system 4 mixing valve amp.                       |                                                                                                                                                                    |
| 47306           | Number    | 1           | 100        | Setting | Climate system 3 mixing valve amp.                       |                                                                                                                                                                    |
| 47307           | Number    | 1           | 100        | Setting | Climate system 2 mixing valve amp.                       |                                                                                                                                                                    |
| 47308           | Number    | 10          | 300        | Setting | Climate system 4 shunt wait                              |                                                                                                                                                                    |
| 47309           | Number    | 10          | 300        | Setting | Climate system 3 shunt wait                              |                                                                                                                                                                    |
| 47310           | Number    | 10          | 300        | Setting | Climate system 2 shunt wait                              |                                                                                                                                                                    |
| 47312           | Switch    | 0           | 1          | Setting | FLM pump 1                                               |                                                                                                                                                                    |
| 47313           | Number    | 1           | 30         | Setting | FLM 1 defrost                                            |                                                                                                                                                                    |
| 47317           | Switch    | 0           | 1          | Setting | Shunt controlled add. accessory                          |                                                                                                                                                                    |
| 47318           | Number    | 5           | 90         | Setting | Shunt controlled add. min. temp.                         |                                                                                                                                                                    |
| 47319           | Number    | 0           | 48         | Setting | Shunt controlled add. min. runtime                       |                                                                                                                                                                    |
| 47320           | Number    | 1           | 100        | Setting | Shunt controlled add. mixing valve amp.                  |                                                                                                                                                                    |
| 47321           | Number    | 10          | 300        | Setting | Shunt controlled add. mixing valve wait                  |                                                                                                                                                                    |
| 47322           | Switch    | 0           | 1          | Setting | Step controlled add. accessory                           |                                                                                                                                                                    |
| 47324           | Number    | 0           | 1000       | Setting | Step controlled add. diff. DM                            |                                                                                                                                                                    |
| 47326           | Switch    | 0           | 1          | Setting | Step controlled add. mode                                |                                                                                                                                                                    |
| 47327           | Switch    | 0           | 1          | Setting | Ground water pump accessory                              |                                                                                                                                                                    |
| 47329           | Switch    | 0           | 1          | Setting | Cooling 2-pipe accessory                                 |                                                                                                                                                                    |
| 47330           | Switch    | 0           | 1          | Setting | Cooling 4-pipe accessory                                 |                                                                                                                                                                    |
| 47335           | Number    | 0           | 48         | Setting | Time betw. switch heat/cool                              |                                                                                                                                                                    |
| 47336           | Number    | 5           | 100        | Setting | Heat at room under temp.                                 |                                                                                                                                                                    |
| 47337           | Number    | 5           | 100        | Setting | Cool at room over temp.                                  |                                                                                                                                                                    |
| 47338           | Number    | 1           | 100        | Setting | Cooling mix. valve amp.                                  |                                                                                                                                                                    |
| 47339           | Number    | 10          | 300        | Setting | Cooling mix. valve step delay                            |                                                                                                                                                                    |
| 47340           | String    | 0           | 18         | Setting | Cooling with room sensor                                 | 0=Off, 1=On                                                                                                                                                        |
| 47341           | Switch    | 0           | 1          | Setting | HPAC accessory                                           | 0=Off, 1=On                                                                                                                                                        |
| 47342           | Number    | 10          | 500        | Setting | Start Passive Cooling DM                                 |                                                                                                                                                                    |
| 47343           | Number    | 10          | 300        | Setting | Start Active Cooling DM                                  |                                                                                                                                                                    |
| 47352           | Switch    | 0           | 1          | Setting | SMS40 accessory                                          |                                                                                                                                                                    |
| 47365           | Switch    | 0           | 1          | Setting | RMU System 1                                             |                                                                                                                                                                    |
| 47366           | Switch    | 0           | 1          | Setting | RMU System 2                                             |                                                                                                                                                                    |
| 47367           | Switch    | 0           | 1          | Setting | RMU System 3                                             |                                                                                                                                                                    |
| 47368           | Switch    | 0           | 1          | Setting | RMU System 4                                             |                                                                                                                                                                    |
| 47370           | Switch    | 0           | 1          | Setting | Allow Additive Heating                                   |                                                                                                                                                                    |
| 47371           | Switch    | 0           | 1          | Setting | Allow Heating                                            |                                                                                                                                                                    |
| 47372           | Switch    | 0           | 1          | Setting | Allow Cooling                                            |                                                                                                                                                                    |
| 47374           | String    | -200        | 400        | Setting | Start Temperature Cooling                                | 0=Off, 1=On                                                                                                                                                        |
| 47375           | Number    | -200        | 400        | Setting | Stop Temperature Heating                                 |                                                                                                                                                                    |
| 47376           | Number    | -250        | 400        | Setting | Stop Temperature Additive                                |                                                                                                                                                                    |
| 47377           | String    | 0           | 48         | Setting | Outdoor Filter Time                                      | 12=Hours 24, 24=Hours                                                                                                                                              |
| 47378           | Number    | 10          | 250        | Setting | Max diff. comp.                                          |                                                                                                                                                                    |
| 47379           | Number    | 10          | 240        | Setting | Max diff. add.                                           |                                                                                                                                                                    |
| 47380           | Switch    | 0           | 1          | Setting | Low brine out autoreset                                  |                                                                                                                                                                    |
| 47381           | Number    | -120        | 150        | Setting | Low brine out temp.EP14                                  |                                                                                                                                                                    |
| 47382           | String    | 1           | 1          | Setting | High brine in                                            | 0=Off, 1=On                                                                                                                                                        |
| 47383           | Number    | 100         | 300        | Setting | High brine in temp.                                      |                                                                                                                                                                    |
| 47384           | String    | 1           | 2          | Setting | Date format                                              | 1=DD-MM-YY, 2=YY-MM-DD                                                                                                                                             |
| 47385           | String    | 12          | 24         | Setting | Time format                                              | 12=hours 24, 24=Hours                                                                                                                                              |
| 47387           | Switch    | 0           | 1          | Setting | HW production                                            | 12=hours 24, 24=Hours                                                                                                                                              |
| 47388           | Switch    | 0           | 1          | Setting | Alarm lower room temp.                                   | 12=hours 24, 24=Hours                                                                                                                                              |
| 47389           | Switch    | 0           | 1          | Setting | Alarm lower HW temp.                                     | 12=hours 24, 24=Hours                                                                                                                                              |
| 47391           | Switch    | 0           | 1          | Setting | Use room sensor S4                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47392           | Switch    | 0           | 1          | Setting | Use room sensor S3                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47393           | Switch    | 0           | 1          | Setting | Use room sensor S2                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47394           | Switch    | 0           | 1          | Setting | Use room sensor S1                                       | 12=hours 24, 24=Hours                                                                                                                                              |
| 47395           | Number    | 50          | 300        | Setting | Room sensor setpoint S4                                  |                                                                                                                                                                    |
| 47396           | Number    | 50          | 300        | Setting | Room sensor setpoint S3                                  |                                                                                                                                                                    |
| 47397           | Number    | 50          | 300        | Setting | Room sensor setpoint S2                                  |                                                                                                                                                                    |
| 47398           | Number    | 50          | 300        | Setting | Room sensor setpoint S1                                  |                                                                                                                                                                    |
| 47399           | Number    | 0           | 60         | Setting | Room sensor factor S4                                    |                                                                                                                                                                    |
| 47400           | Number    | 0           | 60         | Setting | Room sensor factor S3                                    |                                                                                                                                                                    |
| 47401           | Number    | 0           | 60         | Setting | Room sensor factor S2                                    |                                                                                                                                                                    |
| 47402           | Number    | 0           | 60         | Setting | Room sensor factor S1                                    |                                                                                                                                                                    |
| 47413           | Number    | 1           | 100        | Setting | Speed circ.pump HW                                       |                                                                                                                                                                    |
| 47414           | Number    | 1           | 100        | Setting | Speed circ.pump Heat                                     |                                                                                                                                                                    |
| 47415           | Number    | 1           | 100        | Setting | Speed circ.pump Pool                                     |                                                                                                                                                                    |
| 47416           | Number    | 1           | 100        | Setting | Speed circ.pump Economy                                  |                                                                                                                                                                    |
| 47417           | Number    | 1           | 100        | Setting | Speed Circulation Pump Passive Cooling EP14              |                                                                                                                                                                    |
| 47418           | Number    | 1           | 100        | Setting | Speed brine pump                                         |                                                                                                                                                                    |
| 47442           | String    | 0           | 3          | Setting | preset flow clim. sys.                                   | 0=manual setting, 1=radiator, 2=floor heating, 3=radiator + floor heating.                                                                                         |
| 47525           | Number    | 0           | 15         | Setting | Heat Curve S8                                            |                                                                                                                                                                    |
| 47537           | Switch    | 0           | 1          | Setting | Night cooling                                            |                                                                                                                                                                    |
| 47538           | Number    | 20          | 30         | Setting | Start room temp. night cooling                           |                                                                                                                                                                    |
| 47539           | Number    | 3           | 10         | Setting | Night Cooling Min. diff.                                 |                                                                                                                                                                    |
| 47567           | Number    | 0           | 15         | Setting | Heat Curve S7                                            |                                                                                                                                                                    |
| 48043           | String    | 0           | 10         | Setting | Holiday - Activated                                      | 0=inactive, 10=active                                                                                                                                              |
| 48053           | Number    | 0           | 100        | Setting | FLM 2 speed 4                                            |                                                                                                                                                                    |
| 48054           | Number    | 0           | 100        | Setting | FLM 2 speed 3                                            |                                                                                                                                                                    |
| 48055           | Number    | 0           | 100        | Setting | FLM 2 speed 2                                            |                                                                                                                                                                    |
| 48056           | Number    | 0           | 100        | Setting | FLM 2 speed 1                                            |                                                                                                                                                                    |
| 48057           | Number    | 0           | 100        | Setting | FLM 2 speed normal                                       |                                                                                                                                                                    |
| 48058           | Number    | 0           | 100        | Setting | FLM 3 speed 4                                            |                                                                                                                                                                    |
| 48059           | Number    | 0           | 100        | Setting | FLM 3 speed 3                                            |                                                                                                                                                                    |
| 48060           | Number    | 0           | 100        | Setting | FLM 3 speed 2                                            |                                                                                                                                                                    |
| 48061           | Number    | 0           | 100        | Setting | FLM 3 speed 1                                            |                                                                                                                                                                    |
| 48062           | Number    | 0           | 100        | Setting | FLM 3 speed normal                                       |                                                                                                                                                                    |
| 48063           | Number    | 0           | 100        | Setting | FLM 4 speed 4                                            |                                                                                                                                                                    |
| 48064           | Number    | 0           | 100        | Setting | FLM 4 speed 3                                            |                                                                                                                                                                    |
| 48065           | Number    | 0           | 100        | Setting | FLM 4 speed 2                                            |                                                                                                                                                                    |
| 48066           | Number    | 0           | 100        | Setting | FLM 4 speed 1                                            |                                                                                                                                                                    |
| 48067           | Number    | 0           | 100        | Setting | FLM 4 speed normal                                       |                                                                                                                                                                    |
| 48068           | Switch    | 0           | 1          | Setting | FLM 4 accessory                                          |                                                                                                                                                                    |
| 48069           | Switch    | 0           | 1          | Setting | FLM 3 accessory                                          |                                                                                                                                                                    |
| 48070           | Switch    | 0           | 1          | Setting | FLM 2 accessory                                          |                                                                                                                                                                    |
| 48071           | Switch    | 0           | 1          | Setting | FLM 1 accessory                                          |                                                                                                                                                                    |
| 48072           | Number    | -32767      | 32767      | Setting | DM diff start add.                                       |                                                                                                                                                                    |
| 48073           | Switch    | 0           | 1          | Setting | FLM 1 cooling                                            |                                                                                                                                                                    |
| 48074           | Number    | 50          | 400        | Setting | Cool/Heat Sensor Set Point                               |                                                                                                                                                                    |
| 48087           | Switch    | 0           | 1          | Setting | Pool 2 accessory                                         |                                                                                                                                                                    |
| 48088           | Switch    | 0           | 1          | Setting | Pool 1 accessory                                         |                                                                                                                                                                    |
| 48089           | Number    | 50          | 800        | Setting | Pool 2 start temp.                                       |                                                                                                                                                                    |
| 48090           | Number    | 50          | 800        | Setting | Pool 1 start temp.                                       |                                                                                                                                                                    |
| 48091           | Number    | 50          | 800        | Setting | Pool 2 stop temp.                                        |                                                                                                                                                                    |
| 48092           | Number    | 50          | 800        | Setting | Pool 1 stop temp.                                        |                                                                                                                                                                    |
| 48093           | Switch    | 0           | 1          | Setting | Pool 2 Activated                                         |                                                                                                                                                                    |
| 48094           | Switch    | 0           | 1          | Setting | Pool 1 Activated                                         |                                                                                                                                                                    |
| 48120           | Switch    | 0           | 1          | Setting | HW Comfort                                               |                                                                                                                                                                    |
| 48132           | String    | -128        | 127        | Setting | Temporary Lux                                            | 0=Off, 1=3h, 2=6h, 3=12h, 4=One time increase                                                                                                                      |
| 48133           | Number    | 0           | 180        | Setting | Period Pool 2                                            |                                                                                                                                                                    |
| 48139           | Number    | 0           | 2000       | Setting | DM startdiff add. with shunt                             |                                                                                                                                                                    |
| 48142           | Number    | 0           | 2000       | Setting | Step controlled add. start diff DM                       |                                                                                                                                                                    |
| 48144           | Switch    | 0           | 1          | Setting | HW Comfort add during Heat                               |                                                                                                                                                                    |
| 48145           | Switch    | 0           | 1          | Setting | HW Comfort mixing valve                                  |                                                                                                                                                                    |
| 48146           | Number    | 1           | 100        | Setting | HW Comfort mixing valve amp.                             |                                                                                                                                                                    |
| 48147           | Number    | 10          | 300        | Setting | HW Comfort mixing valve wait                             |                                                                                                                                                                    |
| 48148           | Number    | 40          | 65         | Setting | HW Comfort hotwater temperature                          |                                                                                                                                                                    |
| 48157           | Switch    | 0           | 1          | Setting | HW Comfort add.                                          |                                                                                                                                                                    |
| 48174           | Number    | -5          | 30         | Setting | Min cooling supply temp S4                               |                                                                                                                                                                    |
| 48175           | Number    | -5          | 30         | Setting | Min cooling supply temp S3                               |                                                                                                                                                                    |
| 48176           | Number    | -5          | 30         | Setting | Min cooling supply temp S2                               |                                                                                                                                                                    |
| 48177           | Number    | -5          | 30         | Setting | Min cooling supply temp S1                               |                                                                                                                                                                    |
| 48181           | Number    | -5          | 40         | Setting | Own Cooling Curve P3                                     |                                                                                                                                                                    |
| 48185           | Number    | -5          | 40         | Setting | Own Cooling Curve P5                                     |                                                                                                                                                                    |
| 48186           | Switch    | 0           | 1          | Setting | Cooling use mix. valve S4                                |                                                                                                                                                                    |
| 48187           | Switch    | 0           | 1          | Setting | Cooling use mix. valve S3                                |                                                                                                                                                                    |
| 48188           | Switch    | 0           | 1          | Setting | Cooling use mix. valve S2                                |                                                                                                                                                                    |
| 48189           | Number    | 0           | 255        | Setting | Cooling use mix. valve S1                                |                                                                                                                                                                    |
| 48190           | Number    | 10          | 500        | Setting | Heatdump mix. valve delay                                |                                                                                                                                                                    |
| 48191           | Number    | 1           | 100        | Setting | Heatdump mix. valve amp.                                 |                                                                                                                                                                    |
| 48192           | Number    | 10          | 500        | Setting | Cooldump mix. valve delay                                |                                                                                                                                                                    |
| 48193           | Number    | 1           | 100        | Setting | Cooldump mix. valve amp.                                 |                                                                                                                                                                    |
| 48194           | Switch    | 0           | 1          | Setting | ACS accessory                                            |                                                                                                                                                                    |
| 48195           | Switch    | 0           | 1          | Setting | ACS heat dump 24h-function                               |                                                                                                                                                                    |
| 48197           | Number    | 0           | 100        | Setting | ACS closingtime for cool dump                            |                                                                                                                                                                    |
| 48264           | Switch    | 0           | 1          | Setting | Brine shunt accessory                                    |                                                                                                                                                                    |
| 48265           | Number    | 0           | 100        | Setting | Brine shunt amplication                                  |                                                                                                                                                                    |
| 48266           | Number    | 10          | 300        | Setting | Brine shunt wait time                                    |                                                                                                                                                                    |
| 48267           | Number    | 0           | 30         | Setting | Brine shunt, max brine temp                              |                                                                                                                                                                    |
| 48275           | Number    | 50          | 100        | Setting | Max charge pump reg speed                                |                                                                                                                                                                    |
| 48281           | Switch    | 0           | 1          | Setting | Charge method HW                                         |                                                                                                                                                                    |
| 48282           | Switch    | 0           | 1          | Setting | SG Ready heating                                         |                                                                                                                                                                    |
| 48283           | Switch    | 0           | 1          | Setting | SG Ready cooling                                         |                                                                                                                                                                    |
| 48284           | Switch    | 0           | 1          | Setting | SG Ready hot water                                       |                                                                                                                                                                    |
| 48285           | Switch    | 0           | 1          | Setting | SG Ready pool                                            |                                                                                                                                                                    |
| 48286           | Number    | 1           | 100        | Setting | Pool 2 Cpr Percentage                                    |                                                                                                                                                                    |
| 48287           | Number    | 1           | 100        | Setting | Pool 1 Cpr Percentage                                    |                                                                                                                                                                    |
| 48288           | Number    | 1           | 100        | Setting | Cool Cpr Percentage                                      |                                                                                                                                                                    |
| 48452           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, hw                          |                                                                                                                                                                    |
| 48453           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, heat                        |                                                                                                                                                                    |
| 48454           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, pool                        |                                                                                                                                                                    |
| 48455           | Switch    | 0           | 1          | Setting | Auto heat medium pump speed, cool                        |                                                                                                                                                                    |
| 48456           | Number    | 10          | 20         | Setting | Operational mode heat medium pump, cooling               |                                                                                                                                                                    |
| 48458           | Number    | 50          | 100        | Setting | Max speed circ.pump Heat                                 |                                                                                                                                                                    |
| 48459           | Number    | 0           | 100        | Setting | Speed brine pump passive cooling                         |                                                                                                                                                                    |
| 48487           | Number    | 1           | 100        | Setting | Speed Circulation Pump Active Cooling EP14               |                                                                                                                                                                    |
| 48488           | Number    | 0           | 15         | Setting | Heat Curve S6                                            |                                                                                                                                                                    |
| 48489           | Number    | 0           | 15         | Setting | Heat Curve S5                                            |                                                                                                                                                                    |
| 48491           | Number    | -10         | 10         | Setting | Heat Offset S8                                           |                                                                                                                                                                    |
| 48492           | Number    | -10         | 10         | Setting | Heat Offset S7                                           |                                                                                                                                                                    |
| 48493           | Number    | -10         | 10         | Setting | Heat Offset S6                                           |                                                                                                                                                                    |
| 48494           | Number    | -10         | 10         | Setting | Heat Offset S5                                           |                                                                                                                                                                    |
| 48495           | Number    | 50          | 700        | Setting | Min Supply System 8                                      |                                                                                                                                                                    |
| 48496           | Number    | 50          | 700        | Setting | Min Supply System 7                                      |                                                                                                                                                                    |
| 48497           | Number    | 50          | 700        | Setting | Min Supply System 6                                      |                                                                                                                                                                    |
| 48498           | Number    | 50          | 700        | Setting | Min Supply System 5                                      |                                                                                                                                                                    |
| 48499           | Number    | 50          | 800        | Setting | Max Supply System 8                                      |                                                                                                                                                                    |
| 48500           | Number    | 50          | 800        | Setting | Max Supply System 7                                      |                                                                                                                                                                    |
| 48501           | Number    | 50          | 800        | Setting | Max Supply System 6                                      |                                                                                                                                                                    |
| 48502           | Number    | 50          | 800        | Setting | Max Supply System 5                                      |                                                                                                                                                                    |
| 48503           | Number    | -10         | 10         | Setting | External adjustment S8                                   |                                                                                                                                                                    |
| 48504           | Number    | -10         | 10         | Setting | External adjustment S7                                   |                                                                                                                                                                    |
| 48505           | Number    | -10         | 10         | Setting | External adjustment S6                                   |                                                                                                                                                                    |
| 48506           | Number    | -10         | 10         | Setting | External adjustment S5                                   |                                                                                                                                                                    |
| 48507           | Number    | 50          | 300        | Setting | External adjustment with room sensor S8                  |                                                                                                                                                                    |
| 48508           | Number    | 50          | 300        | Setting | External adjustment with room sensor S7                  |                                                                                                                                                                    |
| 48509           | Number    | 50          | 300        | Setting | External adjustment with room sensor S6                  |                                                                                                                                                                    |
| 48510           | Number    | 50          | 300        | Setting | External adjustment with room sensor S5                  |                                                                                                                                                                    |
| 48569           | Switch    | 0           | 1          | Setting | Climate system 5 accessory                               |                                                                                                                                                                    |
| 48570           | Switch    | 0           | 1          | Setting | Climate system 6 accessory                               |                                                                                                                                                                    |
| 48571           | Switch    | 0           | 1          | Setting | Climate system 7 accessory                               |                                                                                                                                                                    |
| 48572           | Switch    | 0           | 1          | Setting | Climate system 8 accessory                               |                                                                                                                                                                    |
| 48573           | Number    | 1           | 100        | Setting | Climate system 8 mixing valve amp.                       |                                                                                                                                                                    |
| 48574           | Number    | 1           | 100        | Setting | Climate system 7 mixing valve amp.                       |                                                                                                                                                                    |
| 48575           | Number    | 1           | 100        | Setting | Climate system 6 mixing valve amp.                       |                                                                                                                                                                    |
| 48576           | Number    | 1           | 100        | Setting | Climate system 5 mixing valve amp.                       |                                                                                                                                                                    |
| 48577           | Number    | 10          | 300        | Setting | Climate system 8 shunt wait                              |                                                                                                                                                                    |
| 48578           | Number    | 10          | 300        | Setting | Climate system 7 shunt wait                              |                                                                                                                                                                    |
| 48579           | Number    | 10          | 300        | Setting | Climate system 6 shunt wait                              |                                                                                                                                                                    |
| 48580           | Number    | 10          | 300        | Setting | Climate system 5 shunt wait                              |                                                                                                                                                                    |
| 48581           | Number    | -5          | 30         | Setting | Min cooling supply temp S8                               |                                                                                                                                                                    |
| 48582           | Number    | -5          | 30         | Setting | Min cooling supply temp S7                               |                                                                                                                                                                    |
| 48583           | Number    | -5          | 30         | Setting | Min cooling supply temp S6                               |                                                                                                                                                                    |
| 48584           | Number    | -5          | 30         | Setting | Min cooling supply temp S5                               |                                                                                                                                                                    |
| 48593           | Switch    | 0           | 1          | Setting | Cooling use mix. valve S8                                |                                                                                                                                                                    |
| 48594           | Switch    | 0           | 1          | Setting | Cooling use mix. valve S7                                |                                                                                                                                                                    |
| 48595           | Switch    | 0           | 1          | Setting | Cooling use mix. valve S6                                |                                                                                                                                                                    |
| 48596           | Switch    | 0           | 1          | Setting | Cooling use mix. valve S5                                |                                                                                                                                                                    |
| 48597           | Switch    | 0           | 1          | Setting | Heating use mix. valve S8                                |                                                                                                                                                                    |
| 48598           | Switch    | 0           | 1          | Setting | Heating use mix. valve S7                                |                                                                                                                                                                    |
| 48599           | Switch    | 0           | 1          | Setting | Heating use mix. valve S6                                |                                                                                                                                                                    |
| 48600           | Switch    | 0           | 1          | Setting | Heating use mix. valve S5                                |                                                                                                                                                                    |
| 48601           | Switch    | 0           | 1          | Setting | Heating use mix. valve S4                                |                                                                                                                                                                    |
| 48602           | Switch    | 0           | 1          | Setting | Heating use mix. valve S3                                |                                                                                                                                                                    |
| 48603           | Switch    | 0           | 1          | Setting | Heating use mix. valve S2                                |                                                                                                                                                                    |
| 48604           | Switch    | 0           | 1          | Setting | Heating use mix. valve S1                                |                                                                                                                                                                    |
| 48607           | Switch    | 0           | 1          | Setting | ERS 1 accessory                                          |                                                                                                                                                                    |
| 48659           | Switch    | 0           | 1          | Setting | Cut off frequency activated 2                            |                                                                                                                                                                    |
| 48660           | Switch    | 0           | 1          | Setting | Cut off frequency activated 1                            |                                                                                                                                                                    |
| 48661           | Number    | 17          | 115        | Setting | Cut off frequency start 2                                |                                                                                                                                                                    |
| 48662           | Number    | 17          | 115        | Setting | Cut off frequency start 1                                |                                                                                                                                                                    |
| 48663           | Number    | 22          | 120        | Setting | Cut off frequency stop 2                                 |                                                                                                                                                                    |
| 48664           | Number    | 22          | 120        | Setting | Cut off frequency stop 1                                 |                                                                                                                                                                    |
| 48675           | Switch    | 0           | 1          | Setting | Use room sensor S8                                       |                                                                                                                                                                    |
| 48676           | Switch    | 0           | 1          | Setting | Use room sensor S7                                       |                                                                                                                                                                    |
| 48677           | Switch    | 0           | 1          | Setting | Use room sensor S6                                       |                                                                                                                                                                    |
| 48678           | Switch    | 0           | 1          | Setting | Use room sensor S5                                       |                                                                                                                                                                    |
| 48680           | Number    | 50          | 300        | Setting | Room sensor setpoint S8                                  |                                                                                                                                                                    |
| 48681           | Number    | 50          | 300        | Setting | Room sensor setpoint S7                                  |                                                                                                                                                                    |
| 48682           | Number    | 50          | 300        | Setting | Room sensor setpoint S6                                  |                                                                                                                                                                    |
| 48683           | Number    | 50          | 300        | Setting | Room sensor setpoint S5                                  |                                                                                                                                                                    |
| 48685           | Number    | 0           | 60         | Setting | Room sensor factor S8                                    |                                                                                                                                                                    |
| 48686           | Number    | 0           | 60         | Setting | Room sensor factor S7                                    |                                                                                                                                                                    |
| 48687           | Number    | 0           | 60         | Setting | Room sensor factor S6                                    |                                                                                                                                                                    |
| 48688           | Number    | 0           | 60         | Setting | Room sensor factor S5                                    |                                                                                                                                                                    |
| 48724           | Number    | 0           | 9          | Setting | Cool curve S8                                            |                                                                                                                                                                    |
| 48725           | Number    | 0           | 9          | Setting | Cool curve S7                                            |                                                                                                                                                                    |
| 48726           | Number    | 0           | 9          | Setting | Cool curve S6                                            |                                                                                                                                                                    |
| 48727           | Number    | 0           | 9          | Setting | Cool curve S5                                            |                                                                                                                                                                    |
| 48728           | Number    | 0           | 9          | Setting | Cool curve S4                                            |                                                                                                                                                                    |
| 48729           | Number    | 0           | 9          | Setting | Cool curve S3                                            |                                                                                                                                                                    |
| 48730           | Number    | 0           | 9          | Setting | Cool curve S2                                            |                                                                                                                                                                    |
| 48731           | Number    | 0           | 9          | Setting | Cool curve S1                                            |                                                                                                                                                                    |
| 48732           | Number    | -10         | 10         | Setting | Cool offset S8                                           |                                                                                                                                                                    |
| 48733           | Number    | -10         | 10         | Setting | Cool offset S7                                           |                                                                                                                                                                    |
| 48734           | Number    | -10         | 10         | Setting | Cool offset S6                                           |                                                                                                                                                                    |
| 48735           | Number    | -10         | 10         | Setting | Cool offset S5                                           |                                                                                                                                                                    |
| 48736           | Number    | -10         | 10         | Setting | Cool offset S4                                           |                                                                                                                                                                    |
| 48737           | Number    | -10         | 10         | Setting | Cool offset S3                                           |                                                                                                                                                                    |
| 48738           | Number    | -10         | 10         | Setting | Cool offset S2                                           |                                                                                                                                                                    |
| 48739           | Number    | -10         | 10         | Setting | Cool offset S1                                           |                                                                                                                                                                    |
| 48740           | Number    | -5          | 40         | Setting | Own Cooling Curve P4                                     |                                                                                                                                                                    |
| 48741           | Number    | -5          | 40         | Setting | Own Cooling Curve P2                                     |                                                                                                                                                                    |
| 48742           | Number    | -5          | 40         | Setting | Own Cooling Curve P1                                     |                                                                                                                                                                    |
| 48743           | Switch    | 0           | 1          | Setting | Hot water high power mode                                |                                                                                                                                                                    |
| 48755           | Number    | 300         | 2500       | Setting | Transformer ratio                                        |                                                                                                                                                                    |
| 48778           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S8                             |                                                                                                                                                                    |
| 48779           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S7                             |                                                                                                                                                                    |
| 48780           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S6                             |                                                                                                                                                                    |
| 48781           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S5                             |                                                                                                                                                                    |
| 48782           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S4                             |                                                                                                                                                                    |
| 48783           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S3                             |                                                                                                                                                                    |
| 48784           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S2                             |                                                                                                                                                                    |
| 48785           | Number    | 50          | 350        | Setting | Room sensor cool setpoint S1                             |                                                                                                                                                                    |
| 48786           | Number    | 0           | 60         | Setting | Room sensor cool factor S8                               |                                                                                                                                                                    |
| 48787           | Number    | 0           | 60         | Setting | Room sensor cool factor S7                               |                                                                                                                                                                    |
| 48788           | Number    | 0           | 60         | Setting | Room sensor cool factor S6                               |                                                                                                                                                                    |
| 48789           | Number    | 0           | 60         | Setting | Room sensor cool factor S5                               |                                                                                                                                                                    |
| 48790           | Number    | 0           | 60         | Setting | Room sensor cool factor S4                               |                                                                                                                                                                    |
| 48791           | Number    | 0           | 60         | Setting | Room sensor cool factor S3                               |                                                                                                                                                                    |
| 48792           | Number    | 0           | 60         | Setting | Room sensor cool factor S2                               |                                                                                                                                                                    |
| 48793           | Number    | 0           | 60         | Setting | Room sensor cool factor S1                               |                                                                                                                                                                    |
| 48794           | Number    | 30          | 90         | Setting | RH set value                                             |                                                                                                                                                                    |
| 48808           | Switch    | 0           | 1          | Setting | HTS accessory                                            |                                                                                                                                                                    |
| 48810           | Switch    | 0           | 1          | Setting | Prevent humidity S8                                      |                                                                                                                                                                    |
| 48811           | Switch    | 0           | 1          | Setting | Prevent humidity S7                                      |                                                                                                                                                                    |
| 48812           | Switch    | 0           | 1          | Setting | Prevent humidity S6                                      |                                                                                                                                                                    |
| 48813           | Switch    | 0           | 1          | Setting | Prevent humidity S5                                      |                                                                                                                                                                    |
| 48814           | Switch    | 0           | 1          | Setting | Prevent humidity S4                                      |                                                                                                                                                                    |
| 48815           | Switch    | 0           | 1          | Setting | Prevent humidity S3                                      |                                                                                                                                                                    |
| 48816           | Switch    | 0           | 1          | Setting | Prevent humidity S2                                      |                                                                                                                                                                    |
| 48817           | Switch    | 0           | 1          | Setting | Prevent humidity S1                                      |                                                                                                                                                                    |
| 48819           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S8                       |                                                                                                                                                                    |
| 48820           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S7                       |                                                                                                                                                                    |
| 48821           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S6                       |                                                                                                                                                                    |
| 48822           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S5                       |                                                                                                                                                                    |
| 48823           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S4                       |                                                                                                                                                                    |
| 48824           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S3                       |                                                                                                                                                                    |
| 48825           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S2                       |                                                                                                                                                                    |
| 48826           | Switch    | 0           | 1          | Setting | Limit humidity in room, heating S1                       |                                                                                                                                                                    |
| 48828           | Switch    | 0           | 1          | Setting | OPT                                                      |                                                                                                                                                                    |
| 48829           | Number    | 10          | 2000       | Setting | OPT DM startdiff                                         |                                                                                                                                                                    |
| 48849           | Number    | 0           | 100        | Setting | Speed brine pump active cooling                          |                                                                                                                                                                    |
| 48850           | Number    | 2           | 10         | Setting | Delta brine pump active cooling                          |                                                                                                                                                                    |
| 48851           | Number    | 0           | 100        | Setting | Waiting speed brine pump cooling                         |                                                                                                                                                                    |
| 48852           | Switch    | 0           | 1          | Setting | Modbus40 Word Swap                                       |                                                                                                                                                                    |
| 48853           | Number    | 0           | 100        | Setting | ERS 1 Exhaust Fan speed 4                                |                                                                                                                                                                    |
| 48854           | Number    | 0           | 100        | Setting | ERS 1 Exhaust Fan speed 3                                |                                                                                                                                                                    |
| 48855           | Number    | 0           | 100        | Setting | ERS 1 Exhaust Fan speed 2                                |                                                                                                                                                                    |
| 48856           | Number    | 0           | 100        | Setting | ERS 1 Exhaust Fan speed 1                                |                                                                                                                                                                    |
| 48857           | Number    | 1           | 100        | Setting | ERS 1 Exhaust Fan speed normal                           |                                                                                                                                                                    |
| 48889           | Switch    | 0           | 1          | Setting | MODBUS40 Disable LOG.SET                                 |                                                                                                                                                                    |
| 48896           | Number    | 0           | 100        | Setting | ERS 1 Supply Fan speed 4                                 |                                                                                                                                                                    |
| 48897           | Number    | 0           | 100        | Setting | ERS 1 Supply Fan speed 3                                 |                                                                                                                                                                    |
| 48898           | Number    | 0           | 100        | Setting | ERS 1 Supply Fan speed 2                                 |                                                                                                                                                                    |
| 48899           | Number    | 0           | 100        | Setting | ERS 1 Supply Fan speed 1                                 |                                                                                                                                                                    |
| 48900           | Number    | 1           | 100        | Setting | ERS 1 Supply Fan speed normal                            |                                                                                                                                                                    |
| 48901           | Number    | 0           | 10         | Setting | External ERS 1 accessory min exhaust temp.               |                                                                                                                                                                    |
| 48902           | Number    | 2           | 10         | Setting | External ERS 1 accessory bypass temp.                    |                                                                                                                                                                    |
| 48908           | Number    | 1           | 10000      | Setting | Energy Meter Factor X23                                  |                                                                                                                                                                    |
| 48909           | Number    | 1           | 10000      | Setting | Energy Meter Factor X22                                  |                                                                                                                                                                    |
| 48910           | Switch    | 0           | 1          | Setting | Energy Meter X23                                         |                                                                                                                                                                    |
| 48911           | Switch    | 0           | 1          | Setting | Energy Meter X22                                         |                                                                                                                                                                    |
| 48918           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S8                       |                                                                                                                                                                    |
| 48919           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S7                       |                                                                                                                                                                    |
| 48920           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S6                       |                                                                                                                                                                    |
| 48921           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S5                       |                                                                                                                                                                    |
| 48922           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S4                       |                                                                                                                                                                    |
| 48923           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S3                       |                                                                                                                                                                    |
| 48924           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S2                       |                                                                                                                                                                    |
| 48925           | Number    | -128        | 127        | Setting | Limit humidity in room, cooling S1                       |                                                                                                                                                                    |
| 48926           | Number    | 5           | 100        | Setting | Humidity factor                                          |                                                                                                                                                                    |
| 48927           | Number    | 0           | 255        | Setting | Humidity cool factor                                     |                                                                                                                                                                    |
| 48928           | Number    | 10          | 2000       | Setting | OPT Hystereses                                           |                                                                                                                                                                    |
| 48930           | Switch    | 0           | 1          | Setting | EME10 Activated                                          |                                                                                                                                                                    |
| 48931           | Switch    | 0           | 1          | Setting | EME PV Panel Affect Heating                              |                                                                                                                                                                    |
| 48932           | Switch    | 0           | 1          | Setting | EME PV Panel Affect Hot Water                            |                                                                                                                                                                    |
| 48948           | Switch    | 0           | 1          | Setting | FLM pump 4                                               |                                                                                                                                                                    |
| 48949           | Switch    | 0           | 1          | Setting | FLM pump 3                                               |                                                                                                                                                                    |
| 48950           | Switch    | 0           | 1          | Setting | FLM pump 2                                               |                                                                                                                                                                    |
| 48951           | Number    | 1           | 30         | Setting | FLM 4 defrost                                            |                                                                                                                                                                    |
| 48952           | Number    | 1           | 30         | Setting | FLM 3 defrost                                            |                                                                                                                                                                    |
| 48953           | Number    | 1           | 30         | Setting | FLM 2 defrost                                            |                                                                                                                                                                    |
| 48954           | Switch    | 0           | 1          | Setting | FLM 4 cooling                                            |                                                                                                                                                                    |
| 48955           | Switch    | 0           | 1          | Setting | FLM 3 cooling                                            |                                                                                                                                                                    |
| 48956           | Switch    | 0           | 1          | Setting | FLM 2 cooling                                            |                                                                                                                                                                    |
| 48957           | Number    | 1           | 100        | Setting | FLM 4 pump speed                                         |                                                                                                                                                                    |
| 48958           | Number    | 1           | 100        | Setting | FLM 3 pump speed                                         |                                                                                                                                                                    |
| 48959           | Number    | 1           | 100        | Setting | FLM 2 pump speed                                         |                                                                                                                                                                    |
| 48960           | Number    | 1           | 100        | Setting | FLM 1 pump speed                                         |                                                                                                                                                                    |
| 48961           | Number    | 10          | 100        | Setting | FLM 4 over temp                                          |                                                                                                                                                                    |
| 48962           | Number    | 10          | 100        | Setting | FLM 3 over temp                                          |                                                                                                                                                                    |
| 48963           | Number    | 10          | 100        | Setting | FLM 2 over temp                                          |                                                                                                                                                                    |
| 48964           | Number    | 10          | 100        | Setting | FLM 1 over temp                                          |                                                                                                                                                                    |
| 48965           | Number    | 50          | 400        | Setting | FLM 4 set point, cooling                                 |                                                                                                                                                                    |
| 48966           | Number    | 50          | 400        | Setting | FLM 3 set point, cooling                                 |                                                                                                                                                                    |
| 48967           | Number    | 50          | 400        | Setting | FLM 2 set point, cooling                                 |                                                                                                                                                                    |
| 48968           | Number    | 50          | 400        | Setting | FLM 1 set point, cooling                                 |                                                                                                                                                                    |
| 48969           | Number    | 0           | 255        | Setting | AUX block OPT                                            |                                                                                                                                                                    |
| 48970           | Switch    | 0           | 1          | Setting | Outdoor Air Mixing function                              |                                                                                                                                                                    |
| 48976           | Switch    | 0           | 1          | Setting | Smart home room control                                  |                                                                                                                                                                    |
| 48977           | Number    | 0           | 100        | Setting | Speed brine pump wait mode                               |                                                                                                                                                                    |
| 48979           | Switch    | 0           | 1          | Setting | Smart energy source                                      |                                                                                                                                                                    |
| 48980           | Switch    | 0           | 1          | Setting | Smart energy source, ctrl method                         |                                                                                                                                                                    |
| 48981           | String    | 0           | 2          | Setting | Smart energy source, electricity price source            | 0=fixed price., 1=tariff., 2=spot price.                                                                                                                           |
| 48982           | Number    | 0           | 10000      | Setting | Smart energy source, electricity price                   |                                                                                                                                                                    |
| 48983           | Switch    | 0           | 1          | Setting | Smart energy source, fixed elec. price from              |                                                                                                                                                                    |
| 48984           | Number    | 0           | 10000      | Setting | Smart energy source, fixed part electricity price        |                                                                                                                                                                    |
| 48985           | Switch    | 0           | 1          | Setting | Smart energy source, shunt add price source              |                                                                                                                                                                    |
| 48986           | Number    | 0           | 10000      | Setting | Smart energy source, shunt add price                     |                                                                                                                                                                    |
| 48987           | Switch    | 0           | 1          | Setting | Smart energy source, ext step add price from             |                                                                                                                                                                    |
| 48988           | Number    | 0           | 10000      | Setting | Smart energy source, ext step add price                  |                                                                                                                                                                    |
| 48989           | Switch    | 0           | 1          | Setting | Smart energy source, OPT10 price source                  |                                                                                                                                                                    |
| 48990           | Number    | 0           | 10000      | Setting | Smart energy source, OPT10 price                         |                                                                                                                                                                    |
| 48991           | Number    | 0           | 50         | Setting | Smart energy source, primary factor elec.                |                                                                                                                                                                    |
| 48992           | Number    | 0           | 50         | Setting | Smart energy source, primary factor shunted add.         |                                                                                                                                                                    |
| 48993           | Number    | 0           | 50         | Setting | Smart energy source, primary factor ext step add         |                                                                                                                                                                    |
| 48994           | Number    | 0           | 50         | Setting | Smart energy source, primary factor OPT10 add.           |                                                                                                                                                                    |
| 48995           | Number    | 1           | 10000      | Setting | Smart energy source, OPT10 high tariff price             |                                                                                                                                                                    |
| 48996           | Number    | 1           | 10000      | Setting | Smart energy source, OPT10 low tariff price              |                                                                                                                                                                    |
| 48997           | Number    | 1           | 10000      | Setting | Smart energy source, ext step add high tariff price      |                                                                                                                                                                    |
| 48998           | Number    | 1           | 10000      | Setting | Smart energy source, ext step add low tariff price       |                                                                                                                                                                    |
| 48999           | Number    | 1           | 10000      | Setting | Smart energy source, shunt add high tariff price         |                                                                                                                                                                    |
| 49000           | Number    | 1           | 10000      | Setting | Smart energy source, shunt add low tariff price          |                                                                                                                                                                    |
| 49001           | Number    | 1           | 10000      | Setting | Smart energy source, fixed elec. high tariff price       |                                                                                                                                                                    |
| 49002           | Number    | 1           | 10000      | Setting | Smart energy source, fixed elec. low tariff price        |                                                                                                                                                                    |
| 49003           | Number    | 1           | 10000      | Setting | Smart energy source, electricity high tariff price       |                                                                                                                                                                    |
| 49004           | Number    | 1           | 10000      | Setting | Smart energy source, electricity high low price          |                                                                                                                                                                    |
| 49005           | Number    | 100         | 2000       | Setting | Smart energy source, DM diff source prio 5               |                                                                                                                                                                    |
| 49006           | Number    | 100         | 2000       | Setting | Smart energy source, DM diff source prio 4               |                                                                                                                                                                    |
| 49007           | Number    | 100         | 2000       | Setting | Smart energy source, DM diff source prio 3               |                                                                                                                                                                    |
| 49008           | Number    | 100         | 2000       | Setting | Smart energy source, DM diff source prio 2               |                                                                                                                                                                    |
| 49009           | Number    | -2000       | -10        | Setting | Smart energy source, DM start source prio 1              |                                                                                                                                                                    |
| 49190           | Switch    | 0           | 1          | Setting | Ground water pump temp alarm                             |                                                                                                                                                                    |
| 49191           | Number    | -15         | 20         | Setting | Ground water pump temp alarm level                       |                                                                                                                                                                    |
| 49192           | Number    | 2           | 10         | Setting | Fixed delta t, brine pump                                |                                                                                                                                                                    |
| 49193           | String    | 0           | 2          | Setting | Brine pump auto controlled                               | 0=manual, 1=auto controlled, 2=fixed delta controlled                                                                                                              |
| 49221           | Number    | 1           | 15         | Setting | Delta brine pump passive cooling                         |                                                                                                                                                                    |
| 49241           | Number    | 5           | 30         | Setting | External ERS 1 accessory bypass set temp.                |                                                                                                                                                                    |
| 49242           | Switch    | 0           | 1          | Setting | External ERS 1 accessory bypass at heat                  |                                                                                                                                                                    |
| 49277           | Number    | 6           | 6          | Setting | FLM 4 fan                                                |                                                                                                                                                                    |
| 49278           | Number    | 6           | 6          | Setting | FLM 3 fan                                                |                                                                                                                                                                    |
| 49279           | Number    | 6           | 6          | Setting | FLM 2 fan                                                |                                                                                                                                                                    |
| 49280           | Number    | 6           | 6          | Setting | FLM 1 fan                                                |                                                                                                                                                                    |
| 49285           | Number    | 1           | 10000      | Setting | Energy Meter pulses per kWh X23                          |                                                                                                                                                                    |
| 49286           | Number    | 1           | 10000      | Setting | Energy Meter pulses per kWh X22                          |                                                                                                                                                                    |
| 49287           | Switch    | 0           | 1          | Setting | Energy Meter mode X23                                    |                                                                                                                                                                    |
| 49288           | Switch    | 0           | 1          | Setting | Energy Meter mode X22                                    |                                                                                                                                                                    |
| 49289           | Switch    | 0           | 1          | Setting | Ground water pump speed control                          |                                                                                                                                                                    |
| 49290           | Switch    | 0           | 1          | Setting | Ground water pump auto speed control                     |                                                                                                                                                                    |
| 49291           | Number    | 1           | 100        | Setting | Ground water pump manual speed                           |                                                                                                                                                                    |
| 49292           | Number    | 0           | 1          | Setting | Ground water pump control signal                         |                                                                                                                                                                    |
| 49293           | Number    | 0           | 80         | Setting | Ground water pump min speed                              |                                                                                                                                                                    |
| 49297           | Switch    | 0           | 1          | Setting | EME20 Activated                                          |                                                                                                                                                                    |
| 49298           | String    | 0           | 255        | Setting | EME PV Panel Affect Pool                                 | 0=not affecting, 1=affecting                                                                                                                                       |
| 49328           | Number    | 0           | 100        | Setting | ERS 4 Exhaust Fan speed 4                                |                                                                                                                                                                    |
| 49329           | Number    | 0           | 100        | Setting | ERS 3 Exhaust Fan speed 4                                |                                                                                                                                                                    |
| 49330           | Number    | 0           | 100        | Setting | ERS 2 Exhaust Fan speed 4                                |                                                                                                                                                                    |
| 49331           | Number    | 0           | 100        | Setting | ERS 4 Exhaust Fan speed 3                                |                                                                                                                                                                    |
| 49332           | Number    | 0           | 100        | Setting | ERS 3 Exhaust Fan speed 3                                |                                                                                                                                                                    |
| 49333           | Number    | 0           | 100        | Setting | ERS 2 Exhaust Fan speed 3                                |                                                                                                                                                                    |
| 49334           | Number    | 0           | 100        | Setting | ERS 4 Exhaust Fan speed 2                                |                                                                                                                                                                    |
| 49335           | Number    | 0           | 100        | Setting | ERS 3 Exhaust Fan speed 2                                |                                                                                                                                                                    |
| 49336           | Number    | 0           | 100        | Setting | ERS 2 Exhaust Fan speed 2                                |                                                                                                                                                                    |
| 49337           | Number    | 0           | 100        | Setting | ERS 4 Exhaust Fan speed 1                                |                                                                                                                                                                    |
| 49338           | Number    | 0           | 100        | Setting | ERS 3 Exhaust Fan speed 1                                |                                                                                                                                                                    |
| 49339           | Number    | 0           | 100        | Setting | ERS 2 Exhaust Fan speed 1                                |                                                                                                                                                                    |
| 49340           | Number    | 1           | 100        | Setting | ERS 4 Exhaust Fan speed normal                           |                                                                                                                                                                    |
| 49341           | Number    | 1           | 100        | Setting | ERS 3 Exhaust Fan speed normal                           |                                                                                                                                                                    |
| 49342           | Number    | 1           | 100        | Setting | ERS 2 Exhaust Fan speed normal                           |                                                                                                                                                                    |
| 49343           | Number    | 0           | 100        | Setting | ERS 4 Supply Fan speed 4                                 |                                                                                                                                                                    |
| 49344           | Number    | 0           | 100        | Setting | ERS 3 Supply Fan speed 4                                 |                                                                                                                                                                    |
| 49345           | Number    | 0           | 100        | Setting | ERS 2 Supply Fan speed 4                                 |                                                                                                                                                                    |
| 49346           | Number    | 0           | 100        | Setting | ERS 4 Supply Fan speed 3                                 |                                                                                                                                                                    |
| 49347           | Number    | 0           | 100        | Setting | ERS 3 Supply Fan speed 3                                 |                                                                                                                                                                    |
| 49348           | Number    | 0           | 100        | Setting | ERS 2 Supply Fan speed 3                                 |                                                                                                                                                                    |
| 49349           | Number    | 0           | 100        | Setting | ERS 4 Supply Fan speed 2                                 |                                                                                                                                                                    |
| 49350           | Number    | 0           | 100        | Setting | ERS 3 Supply Fan speed 2                                 |                                                                                                                                                                    |
| 49351           | Number    | 0           | 100        | Setting | ERS 2 Supply Fan speed 2                                 |                                                                                                                                                                    |
| 49352           | Number    | 0           | 100        | Setting | ERS 4 Supply Fan speed 1                                 |                                                                                                                                                                    |
| 49353           | Number    | 0           | 100        | Setting | ERS 3 Supply Fan speed 1                                 |                                                                                                                                                                    |
| 49354           | Number    | 0           | 100        | Setting | ERS 2 Supply Fan speed 1                                 |                                                                                                                                                                    |
| 49355           | Number    | 1           | 100        | Setting | ERS 4 Supply Fan speed normal                            |                                                                                                                                                                    |
| 49356           | Number    | 1           | 100        | Setting | ERS 3 Supply Fan speed normal                            |                                                                                                                                                                    |
| 49357           | Number    | 1           | 100        | Setting | ERS 2 Supply Fan speed normal                            |                                                                                                                                                                    |
| 49358           | Switch    | 0           | 1          | Setting | Night cooling                                            |                                                                                                                                                                    |
| 49359           | Switch    | 0           | 1          | Setting | Night cooling                                            |                                                                                                                                                                    |
| 49360           | Switch    | 0           | 1          | Setting | Night cooling                                            |                                                                                                                                                                    |
| 49361           | Number    | 20          | 30         | Setting | Start room temp. night cooling                           |                                                                                                                                                                    |
| 49362           | Number    | 20          | 30         | Setting | Start room temp. night cooling                           |                                                                                                                                                                    |
| 49363           | Number    | 20          | 30         | Setting | Start room temp. night cooling                           |                                                                                                                                                                    |
| 49364           | Number    | 3           | 10         | Setting | Night Cooling Min. diff.                                 |                                                                                                                                                                    |
| 49365           | Number    | 3           | 10         | Setting | Night Cooling Min. diff.                                 |                                                                                                                                                                    |
| 49366           | Number    | 3           | 10         | Setting | Night Cooling Min. diff.                                 |                                                                                                                                                                    |
| 49367           | Switch    | 0           | 1          | Setting | ERS 4 accessory                                          |                                                                                                                                                                    |
| 49368           | Switch    | 0           | 1          | Setting | ERS 3 accessory                                          |                                                                                                                                                                    |
| 49369           | Switch    | 0           | 1          | Setting | ERS 2 accessory                                          |                                                                                                                                                                    |
| 49370           | Number    | 0           | 10         | Setting | External ERS 4 accessory min exhaust temp.               |                                                                                                                                                                    |
| 49371           | Number    | 0           | 10         | Setting | External ERS 3 accessory min exhaust temp.               |                                                                                                                                                                    |
| 49372           | Number    | 0           | 10         | Setting | External ERS 2 accessory min exhaust temp.               |                                                                                                                                                                    |
| 49373           | Number    | 2           | 10         | Setting | External ERS 4 accessory bypass temp.                    |                                                                                                                                                                    |
| 49374           | Number    | 2           | 10         | Setting | External ERS 3 accessory bypass temp.                    |                                                                                                                                                                    |
| 49375           | Number    | 2           | 10         | Setting | External ERS 2 accessory bypass temp.                    |                                                                                                                                                                    |
| 49376           | Number    | 5           | 30         | Setting | External ERS 4 accessory bypass set temp.                |                                                                                                                                                                    |
| 49377           | Number    | 5           | 30         | Setting | External ERS 3 accessory bypass set temp.                |                                                                                                                                                                    |
| 49378           | Number    | 5           | 30         | Setting | External ERS 2 accessory bypass set temp.                |                                                                                                                                                                    |
| 49379           | Switch    | 0           | 1          | Setting | External ERS 4 accessory bypass at heat                  |                                                                                                                                                                    |
| 49380           | Switch    | 0           | 1          | Setting | External ERS 3 accessory bypass at heat                  |                                                                                                                                                                    |
| 49381           | Switch    | 0           | 1          | Setting | External ERS 2 accessory bypass at heat                  |                                                                                                                                                                    |
| 49430           | Number    | 0           | 255        | Setting | AUX ERS Fire Place Guard                                 |                                                                                                                                                                    |
